//========================================================================//
// ABOUTDLG.CPP : C++ implementation for the class used to manipulate the
//                About dialog box.  See PORTSETC.DEF for more info.                         //
// Remarks     : Compiled under the large memory model.                   //
// History     : 05/28/95 Original version                                //
//                                                                        //
// Written By  : George Cross                                             //
// Copyright (c) Synergy Solutions Inc,1 2150 S Country Club, Mesa, AZ    // 
//========================================================================//

#include "aboutdlg.h"     //Header containing resource identifiers
#include "portsetc.rh"    //Header containing resource identifiers


//------------------------------------------------------------------------//
// Message map for CAboutDlg class
//------------------------------------------------------------------------//
BEGIN_MESSAGE_MAP(CAboutDlg, CDialog)
   ON_WM_CTLCOLOR () 
END_MESSAGE_MAP()


//------------------------------------------------------------------------//
// FUNCTION        CAboutDlg::CAboutDlg ()
// 
// PARAMETERS      pParentWnd     pointer to the parent window
//
// RETURNS         nothing
//
// CALLED BY       C++ class implementation mechanism
//
// REMARKS         Used to construct the C++ class, attach the dialog resource
//                 and establish the Windows element
//------------------------------------------------------------------------//
CAboutDlg::CAboutDlg(CWnd* pParentWnd) 
          : CDialog(ABOUTDLG, pParentWnd) //Call the parent class constructor
{
 //
 //Set the background brush
 BkgndBrush.CreateSolidBrush (::GetSysColor (COLOR_BTNFACE));
}


//------------------------------------------------------------------------//
// FUNCTION        CAboutDlg::OnInitDialog ()
// 
// PARAMETERS      none
//
// RETURNS         nothing
//
// CALLED BY       MFC mechanism
//
// REMARKS         Used to assign the custom OK button
//------------------------------------------------------------------------//
BOOL CAboutDlg::OnInitDialog() 
{
 //
 //Call the ancestor function
 //
 CDialog::OnInitDialog();

 //
 //Indicate frames and labels are 3D
 //
 Ctl3dSubclassDlg(m_hWnd, CTL3D_STATICTEXTS | CTL3D_STATICFRAMES);                          

 //
 //Load bitmaps for bitmap button (does SubclassButton also)
 //
 OkButton.AutoLoad(IDOK, this);

  
	//=======================================================================//
	//Set the font of the company name to a larger size
 //=======================================================================//
 //
 //Get a pointer to the Synergy window
 //
 CWnd* pWnd = GetDlgItem(IDC_SYNERGY);

	//  
	//Get the current font
	//
	CFont* TheOldFont = pWnd->GetFont();
			       
	//
	//Copy its LOGFONT structure to a variable we can use
	//
	LOGFONT logFont;
	TheOldFont->GetObject( sizeof( LOGFONT ), &logFont );
			 
	//
	//Enlarge the height in the LOGFONT structure, and make it italic
	//
	logFont.lfHeight = (int) (logFont.lfHeight * 1.4);
	logFont.lfWidth = 0;
	logFont.lfEscapement = 0;
	logFont.lfWeight = FW_BOLD; 
	logFont.lfItalic = FALSE;

 //
 //Create a new font based on the modified LOGFONT structure
 //
 NewFont = new CFont();
 NewFont->CreateFontIndirect( &logFont ); 
		
 //
 //Set the new font of the static window
 //
 pWnd->SetFont (NewFont, TRUE);
 
    
 return TRUE;
}


//------------------------------------------------------------------------//
// CAboutDlg::OnCtlColor()
//
// Parameters
//     pDC        Pointer to the display context for the child window
//     pWnd       Pointer to the control asking for color
//     nCtlColor  UINT specifying the type of control. We are interested
//                in only CTLCOLOR_STATIC
//
// Returns        HBRUSH handle to the brush to be used to paint the control
//                background
//
// Called by      Windows mechanism when a child control is about to be 
//                drawn
//
// Remarks        This response function is used to color the text of 
//                the group boxes red
//------------------------------------------------------------------------//
afx_msg HBRUSH CAboutDlg::OnCtlColor(CDC* pDC, CWnd* pWnd, UINT nCtlColor)
{ 
 //
 //Get the ID of the child control
 //
 int ControlID;
 ControlID = pWnd->GetDlgCtrlID();
 
 //
 //If the ID is one of the group boxes..
 //
 if (ControlID == IDC_SYNERGY)
    {
     //
     //Color it 
     //
     pDC->SetTextColor (::GetSysColor (COLOR_HIGHLIGHT)); 
     
     //
     //Set the background mode to transparent
     //
     pDC->SetBkMode (TRANSPARENT);

     //
     //OnCtlColor must return a brush for the background of the control
     //        
     return (HBRUSH) BkgndBrush.GetSafeHandle ();
    }     
  
 //
 //OnCtlColor must return a brush for the background of the control
 //    
 return CDialog::OnCtlColor(pDC, pWnd, nCtlColor);
}

  
//------------------------------------------------------------------------//
// CAboutDlg::PostNcDestroy
// 
// Parameters     None
// Returns        Nothing
// Called By      Windows framework when the Window is destroyed
// Remarks        Destructor for the class to delete the NewFont pointer 
//                and to delete the C++ object from the heap
//------------------------------------------------------------------------//
void CAboutDlg::PostNcDestroy ()
{
   CDialog::PostNcDestroy ();     //Call the base class function
   BkgndBrush.DeleteObject ();    //Delete the GDI object attached to brush
   NewFont->DeleteObject ();      //Delete the GDI object attached to font
   delete NewFont;                //Delete the NewFont object
}
