//=========================================================================//
// DRAGLIST.CPP : C++ source code for the list boxes in the main window    //
//                dialog of the Port Status & Setup program.               //
// Remarks      : Compiled under the large memory model.                   //
// History      : 05/28/95 Original version                                //
//                                                                         //
// Written By   : George Cross                                             //
// Copyright (c) Synergy Solutions Inc,1 2150 S Country Club, Mesa, AZ     // 
//=========================================================================//


#include "draglist.h"      //This module's header for type definitions
#include "maindlg.h"       //Header for the main dialog class
#include "portsetc.rh"     //Header containing resource identifiers


//========================================================================//
// CDragList - Derived, from CListBox, this class is used to manipulate
//             the Available Lines and Available Groups list boxes and 
//             enable dragging list items from the box.
//========================================================================//
BEGIN_MESSAGE_MAP(CDragList, CListBox)
   ON_WM_LBUTTONDOWN()
   ON_WM_MOUSEMOVE()
   ON_WM_LBUTTONUP()
END_MESSAGE_MAP()


CDragList::CDragList(UINT idlistbox, CWnd* parent)      //Class constructor
{
   //
   //Record which control ID to which this object is attached 
   //
   ChildControlID = idlistbox;
   
   //
   //Attach this class to the list box resource template already 
   //created in the PORTSET.RC file       
   //
   SubclassDlgItem(idlistbox, parent);
       
   //
   //Set the tab stops within the Lines list box (MFC function
   //I couldn't get to work)
   //
   int wTabWidth = 76;          //62 dialog units between tabs
   SendMessage(LB_SETTABSTOPS,  //Send the LB_SETTABSTOPS message
               1,               //This window will have only 1 tab stop
               (DWORD)(LPWORD) &wTabWidth); //Pointer to number of dialog
                                            //units in this tab setting   

   //-----------------------------------------------------------------//
   // Below we set a smaller font for the list box windows
   //-----------------------------------------------------------------//
       
   //  
   //First get the current font
   //
   CFont* TheOldFont = GetFont();
       
   //
   //Copy its LOGFONT structure to a variable we can use
   //
   LOGFONT logFont;
   TheOldFont->GetObject( sizeof( LOGFONT ), &logFont );
 
   //
   //Change the weight in the LOGFONT structure. Before it was BOLD
   //
   logFont.lfWeight = FW_MEDIUM;
    
   //
   //Create a new font based on the modified LOGFONT structure
   //
   NewFont = new CFont();
   NewFont->CreateFontIndirect( &logFont ); 

   //
   //Set the new font of the list box windows
   //
   SetFont(NewFont, FALSE);

   //-----------------------------------------------------------------//
   // Set the flag to signal that dragging is not occurring at this time
   //-----------------------------------------------------------------//
   DragOn = FALSE;
   
   hCursor = 0;    //Initialize drag cursor handle 
   
}


//------------------------------------------------------------------------//
// CDragList::OnLButtonDown
//
// Parameters
//     nFlags     unsigned integer signalling other virtual keys which may
//                also be pressed.
//     point      CPoint object specifying the location within the window
//                over where the left mouse button was pressed. 
//
// Returns        Nothing
//
// Called by      Windows when sent the WM_ONLBUTTONDOWN message
//
// Remarks        Overridden function of the CListBox class in which we  
//                record the index of the selected list box item into the 
//                CurrentSelection member of the CDragList class.
//------------------------------------------------------------------------//
afx_msg void CDragList::OnLButtonDown(UINT nFlags, CPoint point)
{
    CListBox::OnLButtonDown(nFlags, point); //Call the ancestor function

    CurrentSelection = GetCurSel();       //Get index of the selected item 
    if ((CurrentSelection == LB_ERR) &&   //If no item is currently selected 
        (GetCount() != 0))                //and there are items in the list
       {
        SetCurSel(0);               //Select the first item 
        CurrentSelection = 0;       //Reflect the index of which item is 
       }
} 


//------------------------------------------------------------------------//
// OnMouseMove - responds to mouse drag operations
//------------------------------------------------------------------------//
afx_msg void CDragList::OnMouseMove(UINT nFlags, CPoint point)
{
   CString stringbuf;        //General purpose character string
   int TabCharPosition;      //Zero based integer holding position in string
   
   if (DragOn == TRUE)
      {
       return;
      }
      
   CListBox::OnMouseMove (nFlags, point);    //Call ancestor function
   
   //
   //The following switch statement determines which status bar message
   //to display in the main dialog depending on which control ID is attached
   //to this list box object  
   //
   switch (ChildControlID)
   {
   case IDC_LIST1:  
       //
       //the mouse is over the LINES list box, so set the status bar
       //text to display the "Available Lines" message
       //
       ((CMainDialog*)GetParent ())->SetStatusBarText (IDS_LINES);
   break;     
   case IDC_LIST2:  
       //
       //The mouse is be over the GROUPS list box, so
       //set the status bar text to the "Available Groups" message
       //
       ((CMainDialog*)GetParent ())->SetStatusBarText (IDS_GROUPS);
   break;
   }   //End    switch (ChildControlID)   
   
   //
   //If the left mouse button is pressed and the list is not empty, then,
   // 
   if ((nFlags & MK_LBUTTON) && (GetCount() != 0))
      {                       
       CurrentSelection = GetCurSel();       //Get index of the selected item 
       if (CurrentSelection == LB_ERR)     //If no item is currently selected 
          {
           SetCurSel(0);               //Select the first item 
           CurrentSelection = 0;       //Reflect the index of which item is 
          } 
       
       //
       //Get the item's character string
       //
       GetText(CurrentSelection, stringbuf);

       //
       //Locate any tab character
       //    
       TabCharPosition = stringbuf.Find("\t");

       //
       //If the value returned is -1 then there is no tab character
       //
       if (TabCharPosition == -1) 
          {
           //
           //There is no tab character so just copy the whole string
           //
           NewAssignment = stringbuf;
          }
       else
          {
           //
           //Otherwise if there is a tab character, copy just the
           //characters preceeding the tab
           //
           NewAssignment = stringbuf.Left(TabCharPosition);
          } 

       //
       // Load new cursor   
       //
       hCursor = AfxGetApp ()->LoadCursor(IDC_SERIALCURSOR);
       HOldCursor = ::SetCursor (hCursor);                  //Set cursor  
       DragOn = TRUE;                //Signal that dragging is occurring
       SetCapture();  //Capture all subsequent mouse movements to this window
      }
}                                                     
  
       
//------------------------------------------------------------------------//
// OnLButtonUp - If the cursor is over one of the ComAssign static windows
//               then the new service name's character string is assigned
//               as the new text of that static window
//------------------------------------------------------------------------//
afx_msg void CDragList::OnLButtonUp(UINT nFlags, CPoint point)
{
   CMainDialog* pMainDlg;           //Pointer to the main dialog 
   CRect LeftRect, RightRect;

   CListBox::OnLButtonUp(nFlags, point); //First call the ancestor function      

   if (DragOn == TRUE)                   //If dragging is occurring then..
      {
       pMainDlg = (CMainDialog*) GetParent();//Assign pointer to main dialog

       //
       //Convert the dimensions of the point where the left mouse button 
       //was released, from those of the CDragList window to those of the
       //main dialog
       //
       MapWindowPoints(pMainDlg, &point, 1); 

       //
       //Iterate for each Windows comm port 
       //
       for (int iloop=0; iloop<=8; iloop++)  
          {
           //
           //Get the dimensions of the window rectangles of the static
           //controls which display the Windows comm port name and the 
           //character string of the MA+ service name to which the
           //Windows comm port is assigned. 
           //
           //The rectangle of the static control displaying the Windows comm
           //port name is returned in LeftRect. The rectangle of the static
           //control displaying the MA+ service name to which the Windows
           //comm port is assigned is returned in RightRect.
           //
           //Each Windows comm port is indexed as 0 through 8 and indicated
           //by the iteration number of this for loop (using the iloop 
           //variable)
           //
           pMainDlg->GetComAssignRects(iloop, LeftRect, RightRect);
           
           //
           //If the left mouse button was released within either the Left
           //rectangle or the Right rectangle then,
           //
           if ((LeftRect.PtInRect(point) == TRUE) || 
               (RightRect.PtInRect(point) == TRUE))
              {
               //
               //Assign the new service name to this comm port by setting 
               //the text of this static control
               //
               pMainDlg->SetComAssign(iloop, NewAssignment);
               
               //
               //Stop iterating since we have already found over which
               //static control the mouse button was released
               //
               break;
              } 
          }
       
       //
       //Don't capture any more mouse messages to the CDragList listbox
       //
       ReleaseCapture();
       
       //
       //Signal that dragging is no longer occurring
       //
       DragOn = FALSE;
       
       //
       //Restore the standard arrow cursor
       //
       ::SetCursor (HOldCursor);
      }
}

  
//------------------------------------------------------------------------//
// CDragList::PostNcDestroy
// 
// Parameters     None
// Returns        Nothing
// Called By      Windows framework when the Window is destroyed
// Remarks        Destructor for the class to delete the NewFont pointer 
//                and to delete the C++ object from the heap
//------------------------------------------------------------------------//
void CDragList::PostNcDestroy()
{
   CListBox::PostNcDestroy();     //Call the base class function
   NewFont->DeleteObject ();      //Delete the GDI object attached to font
   
   //
   //If the drag cursor was assigned loaded then,
   //
   if (hCursor != 0)                             
      {
       DestroyCursor (hCursor);   //Free the memory allocated to cursor
      } 

   delete NewFont;                //Delete the NewFont object
   delete this;                   //Delete this object
}
