//========================================================================//
// GETCLIEN.CPP : C++ source code for the function of the Port Status     //
//                which will retrieve the parameters in the CLIENT.CON    //
//                file.  See PORTSETC.DEF for more information.           //
//               or MCLIENT.TSR. See PORTSETC.DEF for more info.          //
// Remarks     : Compiled under the large memory model.                   //
// History     : 05/28/95 Original version                                //
//                                                                        //
// Written By  : George Cross                                             //
// Copyright (c) Synergy Solutions Inc,1 2150 S Country Club, Mesa, AZ    // 
//========================================================================//

#include "getclien.h"      //Header containing resource identifiers
#include <dos.h>           //DOS header file for some string functions
#include <stdlib.h>        //Standard header file for some string functions
#include <string.h>        //String library for string functions
#include <io.h>            //Header for low-level file handling and I/O 
#include <stdio.h>         //Header for standard I/O routines

/*
---------------------------------------------------------------------
 Global variables used in this module
---------------------------------------------------------------------
*/
struct cparset far * client=NULL;     /* base pointer for client info */
char far file_name[80];
long file_lngth;
int file_handle;
int  num_parsets;
long parsets[PARSETS];
char parset_num[PARSETS][3];
char * parset_ptr;
char far * parset_data;
char * parset_pos;
struct parse_values pdata[20];
int parset_len;
long curpos;
int plen;
int line_len;
char eof_string[] = {26, /* The 1A      */
   0}; /* NULL terminate     */
HGLOBAL hgFileMem;             //Global memory handle for CLIENT.CON file
HGLOBAL hgClientMem;           //Global memory handle for client structure
HGLOBAL hgParsetDataMem;       //Global memory handle for parset data
/*
---------------------------------------------------------------------
 GetClientConValues()
 
 PARAMETERS     
    client_vals     A character pointer to a 51 byte buffer in memory where
                    the function shall copy the values of the CLIENT.CON file.
                    After the function returns, the following CLIENT.CON
                    values may be found at the following offsets from 
                    client_vals:
                    
                    Buffer Size             client_vals[0]
                    Inactivity Timeout      client_vals[7]
                    Nasi Level              client_vals[11]
                    Queue                   client_vals[13]
                    Retry                   client_vals[15]
                    Inbound Service Name    client_vals[17]
                    Connect Dest            client_vals[34]
                    
                    Again, please note that client_vals MUST point to a 
                    buffer of AT LEAST 51 bytes.
                    
    lpszMCIniPath   A pointer to the character string containing the full
                    path to the MCLIENT.INI file. 

 RETURNS            TRUE if there were no errors reading the file.
                    FALSE if there were errors reading the file.
 
 REMARKS:                                        
                                  
 This function, GetClientConValues, is the main function in this
 module which calls all other functions, and which is the only
 external function in the module.

 This function will be called to fill the buffer client_vals
 with the Buffer size, Inactivity timeout, NASI level, Queue,
 Retry, and Inbound Service Name values from the CLIENT.CON file.

 The location of the CLIENT.CON file is retrieved from the FileName=
 statement in the the MCLIENT.INI file located in the WINDOWS
 subdirectory.
---------------------------------------------------------------------
*/
int GetClientConValues(char __far* client_vals,
                       char __far* lpszMCIniPath )
{
int result;
OFSTRUCT far *lpReopenBuff;   /* structure for OpenFile function */

result = Set_Client_Defaults();  /* initialize with default values */
if (result != OK) return(C_ERROR);  /* check that init was successful */

result = GetPrivateProfileString("ClientParms","FileName","client.con",
         file_name, sizeof(file_name), lpszMCIniPath);

hgFileMem = GlobalAlloc(GPTR, sizeof (OFSTRUCT));  /* allocate 140 bytes necessary for*/
lpReopenBuff = (OFSTRUCT far *) GlobalLock(hgFileMem);  /* the lpReopenBuff structure */

file_handle = OpenFile(file_name, lpReopenBuff, OF_READ);
if (file_handle == HFILE_ERROR)
{
 MessageBox(NULL,"Can't open file", file_name, MB_ICONSTOP|MB_OK);
 return(C_ERROR);
}

result = Find_Parsets();   /* locate all the parsets  */
if (result != OK) return(C_ERROR);  /* check that find was successful */

result = Read_Values();     /* read values from chosen parset */
if (result != OK) return(C_ERROR);  /* check that read was successful */

parset_pos = parset_data;   /* point to parset beginning */
parset_len = plen;    /* assign parset length  */

while (parset_len > 0)   /* while there is more buffer */
{
   result = Find_Stmt();   /* go find the next statement */
   switch (result)    /* case statement for return values*/
   {
    case PARSET:   /* Process the PARSET statement     */

 result = Parset_Vals(PARSET); /* go get the values      */
 if (pdata[1].addr != NULL) /* if user gave buffer space     */
 {    /*   overlay the default     */
    strncpy(client->bsize,pdata[1].addr,pdata[1].vlen);
    client->bsize[pdata[1].vlen] = '\0';/* NULL terminate          */
   }
 if (pdata[2].addr != NULL) /* if user gave act time out     */
   {    /*   overlay the default     */
    strncpy(client->act_tout,pdata[2].addr,pdata[2].vlen);
    client->act_tout[pdata[2].vlen] = '\0';/* NULL terminate       */
   }
 break;    /* Exit switch       */

    case SERVER:   /* Process the SERVER statement   */

 result = OK;
 while (result != NOMORE) /* as long as we have keywords     */
   {
    result = Parset_Vals(SERVER); /* go get a keyword      */
    switch (result)  /* depending on the keyword     */
      {
       case NASI:  /* the NASI= keyword      */
  strncpy(client->nasi_level,pdata[0].addr,pdata[0].vlen);
  client->nasi_level[pdata[0].vlen] = '\0';
  break;

       default: break;   /* if not a sought keyword */
      }                                    /* within the SERVER stmnt */
   }
 break;      /* exit the statement switch*/

    case CONNECT:
 result = OK;
 while (result != NOMORE)  /* while we have keywords  */
 {  result = Parset_Vals(CONNECT);  /* go get a keyword      */
    switch (result)   /* depending on the keyword      */
    {

   case DEST:
  strncpy(client->dest,pdata[0].addr,pdata[0].vlen);
  client->dest[pdata[0].vlen] = '\0';
  break;

       case SERVICE:
  strncpy(client->service,pdata[0].addr,pdata[0].vlen);
  client->service[pdata[0].vlen] = '\0';
  break;

       case QUEUE:
  strncpy(client->queue,pdata[0].addr,pdata[0].vlen);
  client->queue[pdata[0].vlen] = '\0';
  break;

       case RETRY:
  strncpy(client->retry ,pdata[0].addr,pdata[0].vlen);
  client->retry[pdata[0].vlen] = '\0';
  break;

       default: break;
    }     /* end of switch for CONNECT */
 }     /* end of while hay more keywords */
 break;     /* exit keyword switch   */

    default: break;
    }      /* end if statement switch  */

}      /* end of while is more data */

lstrcpy(client_vals, client->bsize);
lstrcpy(client_vals + 7, client->act_tout);
lstrcpy(client_vals + 11, client->nasi_level);
lstrcpy(client_vals + 13, client->queue);
lstrcpy(client_vals + 15, client->retry);
lstrcpy(client_vals + 17, client->service);
lstrcpy(client_vals + 17 + IS_LEN + 1, client->dest);

result = _lclose(file_handle);     /* close the client.con file */

GlobalUnlock(hgFileMem);    /* free the allocated 140 bytes */
GlobalFree(hgFileMem);
lpReopenBuff = NULL;

GlobalUnlock(hgClientMem);  /* free the memory allocated for client struct */
GlobalFree(hgClientMem);
client = NULL;

GlobalUnlock(hgParsetDataMem); /* free the memory allocated for parset data*/
GlobalFree(hgParsetDataMem);
parset_data = NULL;

return(OK);
}      /* end of Get_Client_Values  */




/*
--------------------------------------------------------------------
 The function to locate the parsets
--------------------------------------------------------------------
*/
int FAR PASCAL Find_Parsets(void)
{
 char buffer[BUF_LEN+1];  /* Our input buffer        */
 int ln_lngth;    /* Length of line being processed    */
 int len_remains;   /* How much is left in buffer       */
 char eof_sw;    /* Our EOF indicator          */
 int eof_off;    /* Where we find EOF (offset in buf) */
 int buf_off;    /* buffer offset           */
 long counter;    /* where we are in the file       */
 int bytes_read;   /* how much we got from read       */
 int work;     /* working integer          */
 long prev_off;    /* the real beginning         */
 char prev_sw;    /* used to reset the previous offset */
 char fnd_comment;  /* indicated we found comment        */

 eof_sw = 0;    /* the EOF switch           */
 num_parsets=0;    /* We don't have any yet             */
 counter = 0;    /* start at zero           */
 prev_off = 0;    /* for this too            */
 prev_sw = 0;    /* and this             */
 fnd_comment = 0;   /* ditto              */
 file_lngth = 0;   /* double ditto        */

while (eof_sw == 0)   /* As long as we have more data     */
{
 bytes_read = _lread(file_handle, buffer,BUF_LEN);  /* Get a buffer    */

 if (bytes_read == HFILE_ERROR)        /* if we get an error      */
 {
  MessageBox(NULL,"Couldn't read file","Read Error",MB_ICONHAND);        /* Give the message      */
  return(C_ERROR);
 }

 if (bytes_read < BUF_LEN)        /* if we got to end of file     */
 {
  eof_sw = 1;         /* Remember the event           */
 }
 file_lngth = file_lngth + bytes_read; /* accumulate file length */
 buffer[bytes_read] = 0;        /* NULL terminate the string     */
 strupr(buffer);         /* Convert the data to upper case    */

 eof_off = strcspn(buffer,eof_string); /* Search for the EOF character    */

 if (eof_off != BUF_LEN)        /* If the EOF character is here     */
 {
  eof_sw = 1;          /* Remember EOF       */
  if (eof_off == 0)          /* If nothing but EOF      */
   continue;             /* we are done       */
  bytes_read = eof_off;       /* Reduce the amount to process     */
 }

 /*************************************************************************/
 /* Here we retreive each "line" (text between 0D0A characters) and       */
 /* look for the PARSET statements         */
 /*************************************************************************/

 len_remains = bytes_read;        /* Done nothing yet      */

 buf_off = 0;

 ln_lngth = strcspn(buffer+buf_off,"\n\r");   /* Next eol    */

 while (ln_lngth < len_remains)
 {
 /**********************************************************************/
 /* See if this line contains a PARSET statement       */
 /**********************************************************************/

 if ((buffer[buf_off] != ';') && (ln_lngth > 0))
   /* If line is not a comment and is not empty       */
 {
    buffer[buf_off+ln_lngth] = '\0';       /* NULL terminate            */
    work = strspn(buffer+buf_off," \t");   /* First non blank           */
    prev_sw  = 1;              /* need to reset      */

    if ((work < ln_lngth) && buffer[buf_off+work] == 'P')
    { /* If the first non blank is a P       */

  if (strnicmp((buffer+buf_off+work),"PARSET",5) == 0) /* This it?*/
  {
     parset_ptr = buffer+buf_off+work; /* point to beginning     */
     if (fnd_comment == 0) /* if no comments preceeded     */
        parsets[num_parsets] = counter+buf_off;  /* the beginning  */
     else
        parsets[num_parsets] = prev_off;      /* the beginning     */

     /*************************************************************/
     /* Extract and save the PARSET number specified      */
     /*************************************************************/

     parset_num[num_parsets][0] = parset_ptr[6]; /*copy  1st char */

     if ((parset_ptr[7] >= '0') && (parset_ptr[7] <= '9'))
     {        /* If the second character is also a number  */
   parset_num[num_parsets][1] = parset_ptr[7]; /*get 2nd char*/
   parset_num[num_parsets][2] = 0;       /* NULL term  */
     }
     else
     {        /* just terminate the first character     */
   parset_num[num_parsets][1] = 0;       /* NULL term  */
  }

  num_parsets = num_parsets+1;  /* Found another parset     */

  }  /* end of if we found a PARSET statement      */
    } /* End of if first character is a P       */
    fnd_comment = 0;      /* reset found a comment       */
 } /* end of if the line is not a comment and is not empty     */
 else
 {   /* see if we need to reset last begin line  */
  fnd_comment = 1; /* found a comment or blank line     */
  if (prev_sw  == 1)
  {
  prev_off = counter + buf_off;      /* new beginning      */
  prev_sw = 0;
  }
 }
/**** old_off = buf_off;     in case we need to go back*/
  buf_off = buf_off + ln_lngth + 2;        /* Skip the line and the eol */

 len_remains = len_remains - (ln_lngth + 2); /* reduce length     */
 ln_lngth = strcspn(buffer+buf_off,"\n\r");  /* Next eol               */

 if (ln_lngth == len_remains)    /* start here next time   */
 {
/******  buf_off = old_off;      back up to prev line     */
  break;
 }

 } /* End of while more lines exist         */

 counter = counter + buf_off;/* Where we start next time      */

 if (eof_sw != 1)
 lseek(file_handle,counter,SEEK_SET); /* Go to this spot       */
}    /* End of read loop   */

 return(OK);
}    /* End of Find_Parsets */



/*
---------------------------------------------------------------------
  This function reads in the parset 1 values
---------------------------------------------------------------------
*/
int FAR PASCAL Read_Values(void)
{
 int bytes_read;         /* how much we get from the read     */
 const int parset_picked = 0;
 /***************************************************************************/
 /*  The data we want is between parsets[parset_picked] and      */
 /*  parsets[parset_picked+1] or the end of file.       */
 /***************************************************************************/

 if ((parset_picked+1) == num_parsets) /* if we are using the last one     */
  plen = (int) (file_lngth - parsets[parset_picked]);  /* start to EOF    */
 else
  plen = (int) (parsets[parset_picked+1] - parsets[parset_picked]); /* length   */

 /***************************************************************************/
 /* Get the storage to hold the parset information       */
 /***************************************************************************/
 //parset_data  =  (char far *) _fmalloc(plen+1);

 hgParsetDataMem = GlobalAlloc(GPTR,plen+1);
 parset_data = (char __far*) GlobalLock(hgParsetDataMem);

 if (parset_data == NULL)
 {
  MessageBox(NULL,"No storage can be allocated",
   "Read_Values Error",MB_ICONSTOP);    /* can't get it */
  return(C_ERROR);
 }

 /***************************************************************************/
 /* read in the data           */
 /***************************************************************************/

 curpos = lseek(file_handle,parsets[parset_picked],SEEK_SET);/* From start  */

 if (curpos != parsets[parset_picked])
 {
  MessageBox(NULL,"Couldn't set file pointer",
   "Read_Values Error",MB_ICONSTOP);   /* can't get it                           */
  GlobalUnlock(hgParsetDataMem);    /* give back memory       */
  GlobalFree(hgParsetDataMem);
  parset_data = NULL;
  return(C_ERROR);
 }

 bytes_read = _lread(file_handle,parset_data,plen);     /* Get the data    */

 if (bytes_read != plen)
 {
  MessageBox(NULL,"Couldn't read client.con",
   "Read_Values Error",MB_ICONSTOP);   /* can't get it                           */
  GlobalUnlock(hgParsetDataMem);    /* give back memory       */
  GlobalFree(hgParsetDataMem);
  parset_data = NULL;
  return(C_ERROR);
 }

 parset_data[plen] = '\0';        /* NULL terminate                         */
 strupr(parset_data);    /* Convert the data to upper case     */

 /***************************************************************************/
 /* see if we can find the 1A (EOF) character in the buffer      */
 /***************************************************************************/

 parset_len = strcspn(parset_data,eof_string); /* Search for EOF character  */

 if (parset_len != plen)       /* If the EOF character is here    */
   {
  plen = parset_len;       /* Reduce the amount to process    */
  parset_data[plen] = '\0';       /* NULL terminate                    */
   }

 return(OK);         /* all is well      */

} /* End of Read_Values */


/*
---------------------------------------------------------------------
   Find_Stmt points to PARSET,SERVER,TRANSMIT,CONNECT,LINE,GROUP...
   statement keywords
---------------------------------------------------------------------
*/
int FAR PASCAL Find_Stmt()
{
 char * stmt_ptr;               /* points to beginning of statement         */
 int work;                      /* to keep track of offsets                 */

 line_len = strcspn(parset_pos,"\n\r");    /* Next eol                */

 while (parset_len > 0)   /* see if this line has a statment*/
 {
    if ((parset_pos[0] != ';') && (line_len > 0))/* line not comment nor empty*/
    {
 parset_pos[line_len] = '\0';          /* NULL terminate              */
 work = strspn(parset_pos," \t");      /* First non blank             */

 if (work < line_len)                  /* if we found something       */
 {
   stmt_ptr = parset_pos + work;      /* point to character           */

   switch (stmt_ptr[0])               /* First character              */
   {
      case 'P':
        if (strnicmp((stmt_ptr),"PARSET",6) == 0)
   {
    parset_pos[line_len] = '\n'; /* remove NULL terminate     */
    parset_pos = stmt_ptr + 6; /* update position             */
    parset_len = parset_len - (work + 6);/* reduce length     */
    return(PARSET);
   }
      case 'S':
        if (strnicmp((stmt_ptr),"SERVER",6) == 0)
   {
    parset_pos[line_len] = '\n'; /* remove NULL terminate     */
    parset_pos = stmt_ptr + 6; /* update position             */
    parset_len = parset_len - (work + 6);/* reduce length     */
    return(SERVER);
   }
        break;                        /* Exit switch                 */
      case 'C':
  if (strnicmp((stmt_ptr),"CONNECT",7) == 0)
  {
    parset_pos[line_len] = '\n'; /* remove NULL terminate     */
    parset_pos = stmt_ptr + 7; /* update position             */
    parset_len = parset_len - (work + 7);/* reduce length     */
    return(CONNECT);
  }
  break;                        /* Exit switch                 */
      default: break;                 /* Not a sought statement     */
   }                                /* End of switch               */
 }        /* End of line is not empty    */

    } /* end of if the line is not a comment and is not empty             */

    parset_pos = parset_pos + line_len + 2;
    parset_len = parset_len - (line_len + 2);
    line_len = strcspn(parset_pos,"\n\r");    /* Next eol                   */

 } /* End of while more lines exist                                       */

 /***************************************************************************/
 /*  No more statements and we hit the end                                  */
 /***************************************************************************/

 return(OK);
} /* End of Find_Stmt   */


int FAR PASCAL Parset_Vals(int stmt_type)
{
 char * stmt_ptr;               /* points to beginning of statement         */
 int work;                      /* to keep track of offsets                 */
 int vals;

 pdata[0].addr = NULL;    /* so far we have no values                 */

 line_len = strcspn(parset_pos,"\n\r");          /* Next eol                */

 while (parset_len > 0)
 {
    /************************************************************************/
    /* See if this line contains a statement                                */
    /************************************************************************/

    if ((parset_pos[0] != ';') && (line_len > 0))
 /* If line is not a comment and is not empty                        */
    {
       parset_pos[line_len] = '\0';          /* NULL terminate              */

       work = strspn(parset_pos," \t");      /* First non blank             */

       if (work < line_len)                  /* if we found something       */
 {
   stmt_ptr = parset_pos + work;      /* point to character          */

   if (strnicmp((stmt_ptr),"PARSET",6) == 0)
     {
      parset_pos[line_len] = '\n';    /* un NULL terminate           */
      return(NOMORE);                 /* no more keywords            */
     }
   if (strnicmp((stmt_ptr),"SERVER",6) == 0)
     {
      parset_pos[line_len] = '\n';    /* un NULL terminate           */
      return(NOMORE);                 /* no more keywords            */
     }
   if (strnicmp((stmt_ptr),"TRANSMIT",8) == 0)
     {
      if ((stmt_ptr[8]) != '=')        /* could be a keyword         */
        {
  parset_pos[line_len] = '\n'; /* un NULL terminate           */
  return(NOMORE);              /* no more keywords            */
        }
     }
   if (strnicmp((stmt_ptr),"LINE",4) == 0)
     {
      if ((stmt_ptr[5]) != '=')        /* could be LINES=            */
        {
  if ((stmt_ptr[4]) != '=')        /* could be LINE=          */
    {
     parset_pos[line_len] = '\n'; /* un NULL terminate        */
     return(NOMORE);              /* no more keywords         */
    }
        }
     }
   if (strnicmp((stmt_ptr),"GROUP",5) == 0)
     {
      if ((stmt_ptr[5]) != '=')        /* could be a keyword         */
        {
  parset_pos[line_len] = '\n'; /* un NULL terminate           */
  return(NOMORE);              /* no more keywords            */
        }
     }
   if (strnicmp((stmt_ptr),"CONNECT",7) == 0)
     {
      parset_pos[line_len] = '\n';    /* un NULL terminate           */
      return(NOMORE);                 /* no more keywords            */
     }
   if (strnicmp((stmt_ptr),"PERMIT",6) == 0)
     {
      parset_pos[line_len] = '\n';    /* un NULL terminate           */
      return(NOMORE);                 /* no more keywords            */
     }
   if (strnicmp((stmt_ptr),"VCOM",4) == 0)
     {
      parset_pos[line_len] = '\n';    /* un NULL terminate           */
      return(NOMORE);                 /* no more keywords            */
     }

   /******************************************************************/
   /* now we know it's not the next statement                        */
   /******************************************************************/

   switch (stmt_type)                 /* depends on statement type   */
   {
      case PARSET:
  /*************************************************************/
  /* PARSET has no keywords, only positional parms             */
  /*************************************************************/
  pdata[1].addr = NULL;         /*  special case for           */
  pdata[2].addr = NULL;         /*   PARSET                    */
  work = line_len - work;       /* length remaining in line    */

  if (stmt_ptr[0] != ' ' && stmt_ptr[0] != '\t')
   {
    stmt_ptr = stmt_ptr + 2;   /* skip over the parset num    */
    work = work -2;            /* and reduce length           */
   }
  else
   {
    stmt_ptr++;                /* skip over the space     */
    work--;                    /* and reduce length           */
   }
  if (work == 0)                /* if there is nothing here    */
   {
    Next_Line();
    return(OK);
   }

  vals = strspn(stmt_ptr," \t");/* First non blank             */

  if (vals < work)              /* if we found anything        */
   {
    stmt_ptr = stmt_ptr+vals;  /* point to char               */
    work = work - vals;        /* length remaining            */
    vals = strcspn(stmt_ptr,", \t");/* find terminator        */
    if (vals == work || * (stmt_ptr+vals) != ',')
      {                        /* only the one value          */
       pdata[1].addr = stmt_ptr; /* point to bspace           */
       pdata[1].vlen = vals;   /* length                      */
       Next_Line();
       return(OK);
      }
    if (vals == 0)             /* nothing here                */
      {
       Next_Line();
       return(OK);
      }
    pdata[1].addr = stmt_ptr;    /* point to bspace           */
    pdata[1].vlen = vals;      /* length                      */
    stmt_ptr = stmt_ptr+vals+1;/* point to char               */
    work = (work - vals)-1;    /* length remaining            */
    vals = strcspn(stmt_ptr," \t"); /* find terminator        */
    pdata[2].addr = stmt_ptr;  /* point to act timer or log sp*/
    pdata[2].vlen = vals;      /* length                      */
    Next_Line();
    return(OK);
   } /* End of if we found anything */
  Next_Line();
  return(OK);

      case SERVER:
  work = line_len - work;       /* length remaining in line    */

  if (strnicmp((stmt_ptr),"NASI=",5) == 0)
   {                           /* if this is NASI=            */
    stmt_ptr = stmt_ptr+5;     /* over keyword                */
    pdata[0].addr = stmt_ptr;  /* point to data               */
    pdata[0].vlen = 1;      /* length                      */
    Next_Line();
    return(NASI);
   } /* end of if this is NASI= */

      case CONNECT:
  work = line_len - work;       /* length remaining in line    */

  if (strnicmp((stmt_ptr),"QUEUE=",6) == 0)
   {
    stmt_ptr = stmt_ptr+6;
    vals = strcspn(stmt_ptr," \t"); /* length of name         */
    if (vals > 1)                /* if the name is too long     */
      {
       vals = 1;        /* truncate it      */
      }
    pdata[0].addr = stmt_ptr;
    pdata[0].vlen = vals;
    Next_Line();
    return(QUEUE);
   }

  if (strnicmp((stmt_ptr),"RETRY=",6) == 0)
   {
    stmt_ptr = stmt_ptr+6;
    vals = strcspn(stmt_ptr," \t"); /* length of name         */
    if (vals > 1)        /* if the name is too long     */
      {
       vals = 1;        /* truncate it      */
      }
    pdata[0].addr = stmt_ptr;
    pdata[0].vlen = vals;
    Next_Line();
    return(RETRY);
   }

  if (strnicmp((stmt_ptr),"SERVICE=",8) == 0)
   {
    stmt_ptr = stmt_ptr+8;     /* over keyword                */
    vals = strcspn(stmt_ptr," \t"); /* length of name         */
    if (vals > IS_LEN)         /* if the name is too long     */
      {
       vals = IS_LEN;   /* truncate it      */
      }
    pdata[0].addr = stmt_ptr;  /* point to port address       */
    pdata[0].vlen = vals;      /* length                      */
    Next_Line();
    return(SERVICE);
   }      /* end of if this is SERVICE= */

  if (strnicmp((stmt_ptr),"DEST=",5) == 0)
   {
    stmt_ptr = stmt_ptr+5;     /* over keyword                */
    vals = strcspn(stmt_ptr," \t"); /* length of name         */
    if (vals > DN_LEN)         /* if the name is too long     */
    {
     vals = DN_LEN;   /* truncate it      */
    }
    pdata[0].addr = stmt_ptr;  /* point to port address       */
    pdata[0].vlen = vals;      /* length                      */
    Next_Line();
    return(DEST);
   }      /* end of if this is DEST= */

      default: break;                  /* Not a statement we want    */
     }                                /* End of switch               */

 } /* End of if line is not empty                                      */

    } /* end of if the line is not a comment and is not empty             */

    parset_pos = parset_pos + line_len + 2;   /* Skip the line and the eol  */
    parset_len = parset_len - (line_len + 2); /* reduce length              */
    line_len = strcspn(parset_pos,"\n\r");    /* Next eol                   */

   } /* End of while more lines exist                                       */

 /***************************************************************************/
 /*  No more statements and we hit the end                                  */
 /***************************************************************************/

 return(NOMORE);
} /* End of Parset_Vals   */


void FAR PASCAL Next_Line(void)
{
 line_len = line_len+2;                 /* add two for the eol chars       */
 parset_pos = parset_pos + line_len;    /* update position                 */
 parset_len = parset_len - line_len;    /* reduce length                   */
 return;
}           /* end of Next_Line        */



/*
---------------------------------------------------------------------
   Set_Client_Defaults initializes the cparset structure client
---------------------------------------------------------------------
*/
int FAR PASCAL Set_Client_Defaults(void)
{
 /***************************************************************************/
 /*  Get the storage to hold the client info structure                      */
 /***************************************************************************/

 //(char far *) client  = (char far * ) farmalloc(sizeof(struct cparset));
 hgClientMem = GlobalAlloc(GPTR,sizeof(struct cparset));
 client = (struct cparset far *) GlobalLock(hgClientMem);

 if (client == NULL)
   return(ERROR);

 /***************************************************************************/
 /*  Fill in as much as we can                                              */
 /***************************************************************************/

 strcpy(client->num,"1");  /* the parset number       */
 strcpy(client->bsize,"8192");     /* the amount of buffer space            */
 strcpy(client->act_tout,"30");    /* activity timeout                      */
 strcpy(client->psize,"140");
 strcpy(client->ctimer,"60");
 strcpy(client->ptimer,"720");
 strcpy(client->xon,"11H");
 strcpy(client->xoff,"13H");
 strcpy(client->dest,"NULL");
 strcpy(client->service,"NULL");
 strcpy(client->server_name,"SYNERGY");
 strcpy(client->server_timeout,"6");
 strcpy(client->nasi_level,"2");
 strcpy(client->networks,"2");     /* number of networks                    */

 strcpy(client->queue, "Y");
 strcpy(client->retry, "Y");

 /***************************************************************************/
 /*  Set these paramaters to NULL    (not specified)                        */
 /***************************************************************************/

 client->speed[0] = '\0';
 client->parity[0] = '\0';
 client->dbits[0] = '\0';
 client->sbits[0] = '\0';
 client->num_triggers = 0;
 client->phone[0] = '\0';
 client->port[0] = '\0';

 return(OK);
}      /* end of Set_Client_Defaults */

