//------------------------------------------------------------------------//
// GETCLIEN.H   Header file for ABOUTDLG.CPP
//------------------------------------------------------------------------//

//
//If GETCLIEN.H has not already been included in the compile, then,
//                                                                
#ifndef __GETCLIEN_H

//
//Define the inclusion of PORTSET.H and make all the definitions following
//below in this file
//
#define __GETCLIEN_H

#include <windows.h>       //Windows header file for some type definitions

#define OK  0 /* Good return code       */
#define C_ERROR  -1 /* Bad return code       */
/*
---------------------------------------------------------------------
 Define the length maximums for the parameter file
---------------------------------------------------------------------
*/
#define BUF_LEN  512 /* for reading the parameter file */
#define PARSETS  20  /* max number of par sets per file  */
#define SET_LEN  2 /* Sets go from 0 to 99         */
#define STA_LEN  12 /* hex station name          */
#define LN_LEN  16 /* length of a line name        */
#define ES_LEN  32 /* length of external service name    */
#define IS_LEN  16 /* length of internal service name    */
#define DN_LEN  16 /* length of destination name       */
#define GN_LEN  16 /* length of group name         */
#define PN_LEN  24 /* length of default phone number    */
#define IB_LEN  2 /* length of number of inbound lines */
#define TN_LEN  4 /* length of transmit set name     */
#define PT_LEN  5 /* port number            */
#define LT_LEN  5 /* line address            */
#define IL_LEN  1 /* interrupt level          */
#define SP_LEN  6 /* line speed            */
#define PY_LEN  5 /* parity             */
#define DB_LEN  1 /* data bits            */
#define SB_LEN  3 /* stop bits            */
#define PS_LEN  3 /* packet size            */
#define TC_LEN  5 /* character timer          */
#define TP_LEN  5 /* packet timer            */
#define XO_LEN  3 /* XON character           */
#define XF_LEN  3 /* XOFF character           */
#define MAX_TRIG       16 /* max number of triggers     */
#define TG_LEN  3 /* length of single trigger       */
#define PSN_LEN  2 /* parset number           */
#define BS_LEN        10 /* buffer size          */
#define SN_LEN        16 /* server name          */
#define TO_LEN  4 /* activity timer length (min)     */
#define STO_LEN  5 /* server time out (seconds)       */
#define CTO_LEN  2 /* server time out (minutes)      */
#define NL_LEN  1 /* NASI level        */
#define MS_LEN        32 /* modem setup string length      */
#define NW_LEN  3 /* number of networks       */

/*
---------------------------------------------------------------------
  Define the values for statements
---------------------------------------------------------------------
*/
#define PARSET  1
#define TRANSMIT 2
#define CONNECT  3
#define VCOM  4
#define SERVER  5
#define LINE  6
#define GROUP  7
#define PERMIT  8

/*
---------------------------------------------------------------------
 Define the values for keywords
---------------------------------------------------------------------
*/
#define SERVNAME 1
#define TIMEOUT  2
#define TRANNAME 3
#define ALPARS  4
#define DTPARS  5
#define FLOW  6
#define TRIGGERS 7
#define LINENAME 8
#define PORT  9
#define INTERRUPT 10
#define LINETNAME 11
#define MODEM  12
#define CONFERENCE 13
#define PHONE  14
#define INBOUND  15
#define GRPNAME  16
#define GRPTNAME 17
#define LINES  18
#define IDEN  19
#define SERVICE  20
#define CONNGRP  21
#define PERMLINE 22
#define STATIONS 23
#define DEST  24
#define NAME  25
#define QUEUE  26
#define RETRY  27
#define NASI  28
#define NETWORKS 29
#define AUTOBAUD 30
#define NOMORE  50  /* no more keywords      */

#define NONE  99  /* error continuation return     */

/*
---------------------------------------------------------------------
  Global type definitions
---------------------------------------------------------------------
*/
struct cparset     /* the PARSET root structure for client  */
  {
   char num[PSN_LEN+1];     /* the PARSET number       */
   char bsize[BS_LEN+1];    /* amount of buffer size      */
   char act_tout[TO_LEN+1];    /* activity timer       */

       /* the following parameters come from the*/
       /* TRANSMIT statement      */

   char speed[SP_LEN+1];    /* the speed 150-19200      */
   char parity[PY_LEN+1];    /* parity ODD, EVEN, MARK, SPACE, or NONE*/
   char dbits[DB_LEN+1];    /* data bits 5,6,7 or 8      */
   char sbits[SB_LEN+1];    /* stop bits 1,1.5, or 2      */
   char psize[PS_LEN+1];    /* packet size in bytes 1 to 512     */
   char ctimer[TC_LEN+1];    /* character timer 0 to 65535     */
   char ptimer[TP_LEN+1];    /* packet timer- 0 to 65535      */
   char xon[XO_LEN+1];     /* XON character       */
   char xoff[XF_LEN+1];     /* XOFF character       */
   int num_triggers;     /* the number of trigger characters     */
   char triggers[MAX_TRIG] [TG_LEN+1]; /* the set of trigger chars     */
       /* the following parameters come from the*/
       /* CONNECT statement       */
   char dest[LN_LEN+1];     /* line or group to connect      */
   char phone[PN_LEN+1];    /* phone number to dial      */
   char service[IS_LEN+1];    /* respond to this inbound service name  */
   char retry[2];      /* retry option Y or N      */
   char queue[2];      /* queueing option Y or N      */

       /* the following parameters come from the*/
       /* SERVER statement       */

   char server_name[SN_LEN+1];    /* ask for this server name      */
   char server_timeout[STO_LEN+1]; /* server time out (seconds)      */
   char nasi_level[NL_LEN+1];    /* NASI level       */
   char networks[NW_LEN+1];    /* number of networks      */

       /* the following parameters come from the*/
       /* VCOM statement       */

   char port[PT_LEN+1];     /* VCOM IFB address       */
  };

struct parse_values    /* values returned from parse     */
  {
   char * addr;      /* where the value is      */
   int   vlen;      /* length of the char string      */
  };

/*
---------------------------------------------------------------------
 External function prototypes
---------------------------------------------------------------------
*/

int GetClientConValues(char __far* client_vals,
                       char __far* lpszMCIniPath);

/*
---------------------------------------------------------------------
 Resident function prototypes
---------------------------------------------------------------------
*/
int FAR PASCAL Find_Parsets(void);
int FAR PASCAL Read_Values(void);
int FAR PASCAL Find_Stmt(void);
int FAR PASCAL Parset_Vals(int stmt_type);
void FAR PASCAL Next_Line(void);
int FAR PASCAL Set_Client_Defaults(void);


   
//
//End of preprocessor directive to include GETCLIEN.H
//
#endif 