//========================================================================//
// LSERVERS.CPP : C++ source code for the List Servers dialog of the Port //
//               Status & Setup program.  See PORTSETC.DEF for more info. //
// Remarks     : Compiled under the large memory model.                   //
// History     : 05/28/95 Original version                                //
//                                                                        //
// Written By  : George Cross                                             //
// Copyright (c) Synergy Solutions Inc,1 2150 S Country Club, Mesa, AZ    // 
//========================================================================//

#include "lservers.h"           //Header for this source file
#include "portsetc.rh"          //Header containing resource identifiers
#include "ctl3d.h"              //Header for 3D controls library 


//========================================================================//
// Global variable and function declarations
//========================================================================//


//========================================================================//
// CListServers class - This class is used to reference the List Servers
//                   dialog element. The dialog has 1 list box containing
//                   the names of MA+ servers on the network.
//========================================================================//

BEGIN_MESSAGE_MAP(CListServers, CDialog)
   ON_WM_LBUTTONDOWN()
   ON_COMMAND(IDOK, OnOK)
   ON_COMMAND(IDCANCEL, OnOK) 
END_MESSAGE_MAP()

//------------------------------------------------------------------------//
// CListServers() - Constructor for the CListServers class.
//------------------------------------------------------------------------//
CListServers::CListServers ()
{
   Create(LISTSERVERSDLG);                     //Create the dialog element

   //---------------------------------------------------------------------//
   // Below we centre the dialog on the screen...
   //---------------------------------------------------------------------//        
   
   RECT r1;                        //Holds the dialog window dimensions
   int left, top, width, height;   //Variables for moving the window
              
   GetWindowRect(&r1);             //Get the window dimensions
   width = r1.right - r1.left;     //Find the width
   height = r1.bottom - r1.top;    //Find the height
   left = (GetSystemMetrics(SM_CXSCREEN) - width) / 2; //Centre on    
   top = (GetSystemMetrics(SM_CYSCREEN) - height) / 2; //screen
              
   MoveWindow(left, top, width, height, FALSE);        //Place the window

}
  

//------------------------------------------------------------------------//
// CListServers::OnInitDialog
// 
// Parameters     None
// Returns        Boolean. True if focus for a child window was set.
// Called by      Windows mechanism before CListServers::Create (apparently)
// Remarks        Used to indicate which child controls will be 3D
//------------------------------------------------------------------------//
BOOL CListServers::OnInitDialog() 
{
   //
   //Call the ancestor function
   //
   CDialog::OnInitDialog();
   
   //
   //Indicate all except buttons are 3D
   //
   Ctl3dSubclassDlg(m_hWnd, CTL3D_ALL);

   //
   //Load bitmaps for bitmap button (does SubclassButton also)
   //
   OkButton.AutoLoad(IDOK, this);
   
   return TRUE;
}

 
//------------------------------------------------------------------------//
// CListServers::Servers()
//
// Parameters    None
//
// Returns       pointer to a CListBox object (a list box window element)
//
// Called by     CListServers::AddServerName() 
//               CListServers::GetCount() 
//               CListServers::GetText()
//
// Remarks       used to access the Listbox window element in this dialog
//               which shows the available servers.
//------------------------------------------------------------------------//
CListBox* CListServers::Servers()
{
   //
   //Assign pointer to listbox
   //
   return (CListBox*) GetDlgItem(IDC_LIST3);
}   

//------------------------------------------------------------------------//
// AddServerName - Function to add the supplied character to the Server
//                 name list box.
// Parameters  
//    lpszServerName - a far pointer to the character string denoting the
//                   Server name to be added to the list.
//------------------------------------------------------------------------//
void CListServers::AddServerName(const char __far* lpszServerName)
{
   Servers()->AddString(lpszServerName);            //Append a server name to 
}                                                 //the list


//------------------------------------------------------------------------//
// GetCount - Function to return the number of items in the Servers list box
//------------------------------------------------------------------------//
int CListServers::GetCount()
{
   return Servers()->GetCount();                     //Return the number of 
}                                                  //items in the list


//------------------------------------------------------------------------//
// GetText - Function to retrieve the character string of the item in the 
//          Servers list box specified by the zero based index passed 
//          in the first parameter of this function.
// Parameters
//    nIndex - zero based index of the list box item to retrieve.
//    lpszBuffer - empty character string to receive the character string 
//               requested
//------------------------------------------------------------------------//
int CListServers::GetText(int nIndex, LPSTR lpszBuffer)
{
   return Servers()->GetText(nIndex, lpszBuffer); //Return the character string
}                                               //of item nIndex in the list


//------------------------------------------------------------------------//
// CListServers::OnOK
//
// Parameters     None
//
// Returns        Nothing
//
// Called by      Windows mechanism when the dialog receives the 
//                WM_CLOSE message
//                                
// Remarks        Overridden ancestor function used to release the captured
//                mouse from this window
//------------------------------------------------------------------------//
afx_msg void CListServers::OnOK()
{
   CDialog* pMainDlg;       //Pointer to the main dialog 
   pMainDlg = (CDialog*) AfxGetMainWnd();//Assign pointer to main dialog

   //
   //Re enable the main dialog 
   //
   pMainDlg->EnableWindow(TRUE);

   //
   //Re activate the main dialog
   //
   pMainDlg->SetFocus();

   //
   //Call ancestor function. This calls EndDialog which will hide the 
   //dialog window. We may want to use this dialog again so we do this
   //instead of overriding OnOK and calling DestroyWindow.
   //
   //DestroyWindow is called in CMainDialog::OnCloseClick
   //
   CDialog::OnOK();
}
 
 
