//========================================================================//
// MAINDLG.CPP : C++ source code for the main dialog window of the Port   //
//               Status & Setup program. See PORTSETC.DEF for more info.  //
// Remarks     : Compiled under the large memory model.                   //
// History     : 05/28/95 Original version                                //
//                                                                        //
// Written By  : George Cross                                             //
// Copyright (c) Synergy Solutions Inc,1 2150 S Country Club, Mesa, AZ    // 
//========================================================================//

#include "maindlg.h"      //This module's header for type definitions
#include "messages.h"     //Header containing all string constants
#include "portsetc.rh"    //Header containing resource identifiers
#include "ctl3d.h"        //Header for 3D controls library 
#include "portsetc.h"     //Header for the PORTSETC.CPP source module


//========================================================================//
// Global variables and functions...                                      //
//========================================================================//

extern HINSTANCE  hinstMClient;      // handle to MCLIENT.DLL
extern HWND       ghDlg;             // handle to the main dialog
extern char __far lpszMCIniPath[60]; // File path to MCLIENT.INI file
extern BOOL TSRLoaded;               // flag indicating MCLIENT.EXE is loaded

extern int IsLoaded ();              // Checks to see if MCLIENT.EXE loaded

//========================================================================//
// CMainDialog client window class.  This class will be used to construct
// and manipulate the main dialog for the PORTSET.EXE application.                               
//========================================================================//

//------------------------------------------------------------------------//
// Message Map for CMainDialog class.  This is a map declaring which 
// Windows messages - generated by the Windows window element held by 
// CMainDialog class - will call which functions of the CMainDialog class.
//------------------------------------------------------------------------//
BEGIN_MESSAGE_MAP (CMainDialog, CDialog)   
   ON_COMMAND    (CM_REFRESH,       OnRefresh)     //File|Refresh F5 on menu
   ON_COMMAND    (CM_SAVE,          OnSave)        //File|Save on menu
   ON_COMMAND    (IDC_LISTSERVERS,  OnListServers) //Click List Servers bttn 
   ON_COMMAND    (IDC_MOREDETAIL,   OnMoreDetail)  //Click More Detail button
   ON_COMMAND    (CM_USAGE,         OnUsage)       //Select Help|Usage on menu
   ON_COMMAND    (IDC_ABOUT,        OnAbout)       //Click the About button
   ON_COMMAND    (IDC_MACOMMDRV,    OnInstallMACOMM) //Install MACOMM.DRV
   ON_COMMAND    (IDC_EXIT,         OnExitClick)     //Click the Exit button
   ON_COMMAND    (IDOK,             OnOK)
   ON_COMMAND    (IDCANCEL,         OnCancel)
   ON_WM_CTLCOLOR () 
   ON_WM_LBUTTONDBLCLK ()
   ON_WM_SYSCOLORCHANGE ()
   ON_WM_MOUSEMOVE ()
   ON_WM_WINDOWPOSCHANGED ()
   ON_WM_CLOSE ()
   ON_WM_DESTROY ()
//   ON_WM_NCDESTROY ()
END_MESSAGE_MAP ()  


//------------------------------------------------------------------------//
// Constructor for CMainDialog class. Here we create the Windows window   
// element, centre the dialog on the screen and assign the menu
//------------------------------------------------------------------------//
CMainDialog::CMainDialog ()
{
   Create (MAINPORTSETDLG);      //Create the dialog using the dialog
                                 //resource in PORTSETC.RC 
   
   //
   //Set the icon for the main window, shown upon minimizing
   //
   ::SetClassWord(m_hWnd,         //Handle this window element
                  GCW_HICON,      //Specify the WNDCLASS.hIcon element
                  (WORD)          //Cast handle of icon loaded above to WORD
                  ((CApp*) AfxGetApp ())->PortSetIcon); //Custom icon handle
   
   //
   //Create subclasses to manipulate the listboxes holding Available Lines
   //and Groups service names
   //
   Lines = new CDragList(IDC_LIST1, this);
   Groups = new CDragList(IDC_LIST2, this);
          
   //
   //Iterate for each virtual Windows comm port
   //
   for (int iloop=0; iloop<=8; iloop++)  //Iterate for each Windows comm port
      { 
       //
       //Create a subclass to manipulate the static controls which display
       //the character string of the MA+ service name to which this 
       //particular Windows comm port is assigned
       //
       ComAssign[iloop] =                  
       new CDropStatic(COM1DEST + iloop,     //The static control's ID
                       this);                //A pointer to parent window
      } 
   
   //
   //Fill the dialog's labels and listboxes with the appropriate
   //MA+ information.  
   //   
   if (!GetMAValues())       //If unsuccessful,
      {
       SendMessage (WM_CLOSE);           //Close the application
       return;
      }
      
   //
   //Check that MACOMM.DRV is entered in the SYSTEM.INI file
   //
   CheckForMACOMMDRV ();   
                             
   //---------------------------------------------------------------------//
   // Below we centre the dialog on the screen...
   //---------------------------------------------------------------------//  
   RECT r1;                        //Holds the dialog window dimensions
   int left, top, width, height;   //Variables for moving the window
  
   GetWindowRect(&r1);             //Get the window dimensions
   width = r1.right - r1.left;     //Find the width
   height = r1.bottom - r1.top;    //Find the height
   left = (GetSystemMetrics(SM_CXSCREEN) - width) / 2; //Centre on  
   top = (GetSystemMetrics(SM_CYSCREEN) - height) / 2; //screen
  
   MoveWindow(left, top, width, height, FALSE);        //Place the window

   CMenu* m;                            //Declare a menu pointer
   m = GetSystemMenu(FALSE);            //Assign it to the System menu
   m->ModifyMenu(SC_SIZE, MF_GRAYED);   //Eliminate the Size option

   //
   // Below we assign the global handle to the dialog. Used later..
   // 
   ghDlg = m_hWnd;   

   //
   //Remove the splash window
   //                                                  
   ((CApp*) AfxGetApp())->SplashWindow->TakeDown();
}
  
  
//------------------------------------------------------------------------//
// CMainDialog::OnInitDialog
// 
// Parameters     None
// Returns        Boolean. True if focus for a child window was set.
// Called by      Windows mechanism before CMainDialog::Create (apparently)
// Remarks        Used to indicate which child controls will be 3D
//------------------------------------------------------------------------//
BOOL CMainDialog::OnInitDialog() 
{
   //
   //Call the ancestor function
   //
   CDialog::OnInitDialog();
   
   //
   //Indicate all are 3D
   //
   Ctl3dSubclassDlg(m_hWnd, CTL3D_LISTBOXES    | 
                            CTL3D_BUTTONS      |
                            CTL3D_STATICTEXTS  |
                            CTL3D_STATICFRAMES |
                            CTL3D_EDITS        |
                            CTL3D_COMBOS       );                          

   //
   //Load bitmaps for each of 5 bitmap buttons (does SubclassButton also)
   //
   for (int iloop = 0; iloop < 5; iloop++)
      {
       //
       //Load the bitmaps for each button state
       //
       Buttons[iloop].AutoLoad(IDC_ABOUT + iloop, this);
      }

   //
   //Set the brush of the dialog background 
   //GetDC()->GetBkColor()); For some reason did not return the correct
   //background color. 
   //
   BackgroundBrush.CreateSolidBrush(::GetSysColor(COLOR_BTNFACE));
   
   return TRUE;
}

 
//------------------------------------------------------------------------//
// CMainDialog::InitStatusBar ()
//
// PARAMETERS     None
//
// RETURNS        Nothing
//
// CALLED BY      CMainDialog::OnWindowPosChanged ()
//
// REMARKS        Used to retreive the child window rectangles which will 
//                be the "hot spots" for displaying the status bar text when
//                the mouse is dragged over them.
//------------------------------------------------------------------------//
void CMainDialog::InitStatusBar ()
{
 //
 //Get a pointer to the status bar window
 //
 CWnd* pWndStatusBar = GetDlgItem (IDC_STATUSBAR);
 
 //
 //Get the device context in which we need to calculate a new font height
 //
 CClientDC DC (pWndStatusBar);

 //
 //Calculate the height we want to use for the new font
 //
 HeightStatusBarFont = MulDiv(-8.5, DC.GetDeviceCaps (LOGPIXELSY), 72);
 
 //
 //Get the pointers to the windows of each of the following child controls
 // 
 CWnd* pWndLinesFrame = GetDlgItem (IDC_LINESFRAME);
 CWnd* pWndGroupsFrame = GetDlgItem (IDC_GROUPSFRAME);
 CWnd* pWndPortsFrame = GetDlgItem (IDC_PORTSFRAME);
 CWnd* pWndStatusFrame = GetDlgItem (IDC_STATUSFRAME);
 CWnd* pWndActiveLinesIcon = GetDlgItem (IDC_ACTIVELINES_ICON);
 CWnd* pWndClientInUseIcon = GetDlgItem (IDC_CLIENTINUSE_ICON);
    
 //
 //Now get the window rectangles of these static controls. Note that
 //GetWindowRect () returns SCREEN coordinates.
 //
 CRect StatusFrameRect,         //Rectangle dimensions necessary only for 
       ActiveLinesIconRect,     //this function to calculate the dimensions
       ClientInUseIconRect;     //for other rectangles
 
 pWndLinesFrame->GetWindowRect (LinesRect);
 pWndGroupsFrame->GetWindowRect (GroupsRect);
 pWndPortsFrame->GetWindowRect (PortsRect);
 pWndStatusFrame->GetWindowRect (StatusFrameRect);
 pWndActiveLinesIcon->GetWindowRect (ActiveLinesIconRect);
 pWndClientInUseIcon->GetWindowRect (ClientInUseIconRect);
 
 //
 //Now we divide the StatusFrameRect into three rectangles. The 
 //StatusFrameRect encloses the three icons and status labels in the top
 //of the main dialog (see PORTSET.RC). As the mouse is moved over each
 //of these three areas, we want to change the text displayed in status bar
 //at the bottom of the main dialog. 
 //
 ActiveServersRect.SetRect (StatusFrameRect.left,     //Rectangle left
                            StatusFrameRect.top,      //top
                            ActiveLinesIconRect.left, //right
                            StatusFrameRect.bottom);  //bottom 
                            
 ActiveLinesRect.SetRect (ActiveLinesIconRect.left,
                          StatusFrameRect.top,
                          ClientInUseIconRect.left,
                          StatusFrameRect.bottom);
                          
 ClientInUseRect.SetRect (ClientInUseIconRect.left,
                          StatusFrameRect.top,
                          StatusFrameRect.right,
                          StatusFrameRect.bottom);
                          
 //
 //In the function CMainDialog::OnMouseMove (), we use the rectangles
 //calculated above, and summarized below to determine which message to
 //display in the status bar at the bottom of the main dialog.
 //
 // LinesRect            Available Lines / State rectangle
 // GroupsRect           Available Groups rectangle
 // PortsRect            Virtual Comm Port Assignments rectangle
 // ActiveServersRect    Active Servers icon and static label
 // ActiveLinesRect      Active Lines icon and static label
 // ClientInUseRect      Client In Use = DLL / TSR icon and static label
 //
}


//------------------------------------------------------------------------//
// GetMAValues - Called after the dialog window is created. In this 
//    function we assign global pointers and also call the 
//    IsLoaded function, ordinal 2 in PORTSET.DLL to determine
//    if MCLIENT.EXE is loaded. Subsequently, we either call
//    CMainDialog::GetNamesTSR, or CMainDialog::LoadMClientDLL 
//    and CMainDialog::GetNamesDLL.
//------------------------------------------------------------------------// 
BOOL CMainDialog::GetMAValues ()
{
   int xvalue;                    //General purpose function return value
   NumLines = 0;                         //Initialize the Lines counter       
   ComAssignsChanged = FALSE;            //Signal no comm assignments have
                                         //been modified at this time
 
   //
   // Read the MCLIENT.INI file to retrieve.
   //
   xvalue = ReadMClientINI(); 
   
   //
   //If ReadMClientINI() function call was unsuccessful..
   //
   if (xvalue == FALSE)
      {
       //
       //Return FALSE, hence aborting application. An error message
       //will already have been displayed from within ReadMClientINI
       //                                                           
       return FALSE;
      }

   //---------------------------------------------------------------------//
   // Below we call the IsLoaded function to determine whether the 
   // MCLIENT.EXE TSR is present in memory.  If so, call GetNamesTSR...
   //---------------------------------------------------------------------//
   TSRLoaded = IsLoaded ();   //Call IsLoaded 

   if (TSRLoaded == TRUE)           //If MCLIENT.EXE is in memory then,
      {
       TSRLabel();                  //Change dialog label to show TSR in use
       if (!GetNamesTSR())          //Call GetNamesTSR to retrieve MA+ 
          { return FALSE; }         //service names. Abort if unsuccessful
      }            
       
   //---------------------------------------------------------------------//
   // Below, since the the MCLIENT.EXE TSR is not loaded, we load
   // MCLIENT.DLL, return immediately if there is a problem, and then
   // call GetNamesDLL to retrieve MA+ service names.
   //---------------------------------------------------------------------// 
   else 
      {
       if (!LoadMClientDLL())      //Load MCLIENT.DLL 
          { return FALSE; }        //Abort if can't load MCLIENT.DLL
        
       if (!GetNamesDLL())       //Call GetNamesDLL to retrieve MA+ 
          { return FALSE; }    //service names. Abort if unsuccessful
      }
   LinesLabel();        //Displays number of Lines Found

   return TRUE;   
}


//------------------------------------------------------------------------//
// CMainDialog::OnWindowPosChanged ()
//
// PARAMETERS     None
//
// RETURNS        Nothing
//
// CALLED BY      Windows messaging mechanism
//
// REMARKS        Used to recalculate the screen positions of the child
//                windows which cause the status bar to display text when
//                the mouse is dragged over them.
//------------------------------------------------------------------------//
afx_msg void CMainDialog::OnWindowPosChanged (WINDOWPOS FAR* lpwndpos)
{            
 //
 //Initialize the status bar in the bottom of the dialog
 //
 InitStatusBar ();
}


//
//------------------------------------------------------------------------//
// OnSysColorChange - Overridden function to pass on a system color change
//        to CTL3D 3D controls.
//------------------------------------------------------------------------//
afx_msg void CMainDialog::OnSysColorChange ()
{
   //
   //When not using 3D controls, use CWnd::OnSysColorChange();
   //
   Ctl3dColorChange();
}


//------------------------------------------------------------------------//
// CMainDialog::OnCtlColor()
//
// Parameters
//     pDC        Pointer to the display context for the child window
//     pWnd       Pointer to the control asking for color
//     nCtlColor  UINT specifying the type of control. We are interested
//                in only CTLCOLOR_STATIC
//
// Returns        HBRUSH handle to the brush to be used to paint the control
//                background
//
// Called by      Windows mechanism when a child control is about to be 
//                drawn
//
// Remarks        This response function is used to color the text of 
//                the group boxes red
//------------------------------------------------------------------------//
afx_msg HBRUSH CMainDialog::OnCtlColor(CDC* pDC, CWnd* pWnd, UINT nCtlColor)
{
 //
 //Get the ID of the child control
 //
 int ControlID;
 ControlID = pWnd->GetDlgCtrlID();
 
 //
 //If the ID is one of the group boxes..
 //
 if (ControlID == IDC_LINESFRAME  || ControlID == IDC_GROUPSFRAME ||
     ControlID == IDC_PORTSFRAME  || ControlID == IDC_STATUSFRAME ||
     ControlID == IDC_STATUSBAR)
    {
     //
     //Color it red
     //
     pDC->SetTextColor (::GetSysColor (COLOR_HIGHLIGHT));
     
     //
     //Set the background color since it wasn't getting set in Win95
     //
     pDC->SetBkColor (::GetSysColor (COLOR_BTNFACE)); 
     
     //
     //OnCtlColor must return a brush for the background of the control
     //    
     return (HBRUSH) BackgroundBrush.GetSafeHandle ();
    }     
 
 //
 //OnCtlColor must return a brush for the background of the control
 //    
 return CDialog::OnCtlColor(pDC, pWnd, nCtlColor);
}


//------------------------------------------------------------------------//
// OnLButtonDblClk - If the cursor is over one of the ComAssign static
//                   windows, then that static's text is set to "Local"
//------------------------------------------------------------------------//
afx_msg void CMainDialog::OnLButtonDblClk(UINT nFlags, CPoint point)
{
   //
   //Rectangle structures to hold the window dimensions of the static 
   //controls associated with each particular Windows comm port
   //
   //Each Window's comm port has two static contols in our main dialog.
   //The left control displays the comm port name. The right control 
   //displays the MA+ service name to which the comm port is assigned
   //
   CRect LeftRect, RightRect;       

   //
   //First call the ancestor function
   //
   CDialog::OnLButtonDblClk(nFlags, point);

   //
   //Iterate for each Windows comm port
   //
   for (int iloop=0; iloop<=8; iloop++)  
      {                                  
       //
       //Get the rectangle dimensions of the indexed static control's window
       //
       GetComAssignRects(iloop, LeftRect, RightRect);
       
       //
       //If the left mouse button was double clicked within either window
       //
       if ((LeftRect.PtInRect(point) == TRUE) ||
           (RightRect.PtInRect(point) == TRUE))
          {                                                            
           //
           //Reset the static control's text to display "Local"
           //
           SetComAssign(iloop, "Local");
           
           //
           //Stop iterating since we have already found the static control
           //over which the left mouse button was double clicked
           //
           break;
          } 
      }
}


//------------------------------------------------------------------------//
// OnRefresh - refreshes the Available Lines and Available Groups list boxes
//        when the user either selects File|Refresh or presses F5
//-----------------------------------------------------------------------//
afx_msg void CMainDialog::OnRefresh ()
{
   ((CApp*) AfxGetApp())->DoWaitCursor (1);
   _fmemset(LineInfo.ServerName, '?', 48); // add 16 '?'s each for Server,
                                         // Group and Line names  
   NumLines = 0;
   ::LockWindowUpdate(m_hWnd);    //Don't update the screen yet               
   
   SendDlgItemMessage(IDC_LIST1, LB_RESETCONTENT, 0, 0);  //Clear list boxes
   SendDlgItemMessage(IDC_LIST2, LB_RESETCONTENT, 0, 0); 
   ListServersDlg.SendDlgItemMessage(IDC_LIST3, LB_RESETCONTENT, 0, 0); 
   
   if (TSRLoaded)  GetNamesTSR();  //If the TSR is loaded use GetNamesTSR                
   else  GetNamesDLL();                 //Otherwise call GetNamesDLL
   LinesLabel();                        //Update the number of lines label
   
   ::LockWindowUpdate(NULL);            //Now permit updates to the screen
   Invalidate();                        //Invalidate to send WM_PAINT message
   UpdateWindow();                      //Update now!
   
}  


//------------------------------------------------------------------------//
// CMainDialog::QuerySaveAndExit()
// 
// Parameters   None
// 
// Returns      TRUE to continue with exiting. FALSE to abort exit procedure.
//
// Called by    CMainDialog::CloseApp()
//
// Remarks      Used to ask user "Save Changes before Exiting?" and respond
//              accordingly
//------------------------------------------------------------------------//
BOOL CMainDialog::QuerySaveAndExit()
{
   int   Response;               //Response to message box prompts
   BOOL  ContinueExiting = TRUE; //Signals continue or abort exit procedure
   
   //
   //If the flag signals that a Windows comm port assignment was changed,
   //
   if (ComAssignsChanged == TRUE)
      {
       //
       //Ask "Save Changes Before Exiting?"
       //
       Response = 
       MessageBox(SAVE_CHANGES, APP_TITLE, MB_ICONQUESTION|MB_YESNOCANCEL);
       
       switch (Response)
       {
       case IDYES:  //User responded Yes to save changes
          
          //
          //Save the settings
          //
          SaveSettings();
          
          //
          //Ask for "Reboot windows?"
          //
          Response = 
          MessageBox(RESTART_WINDOWS, APP_TITLE, MB_ICONQUESTION|MB_YESNO);
          
          //
          //If response was Yes to reboot windows, then reboot windows
          //
          if (Response == IDYES)
             {
              ExitWindows(EW_RESTARTWINDOWS, 0); 
             }
          
       break;          //Case IDYES
       case IDNO:      //User responded No to save changes.
          
          //
          //Don't do anything, just continue to close the app
          //
       break;          //Case IDNO
       case IDCANCEL:  //User responded Cancel to save changes, so...
          
          //
          //Signal to abort exit procedure
          //
          ContinueExiting = FALSE;
       break;
      }   //End of switch (Response) statement
     }    //End of if (ComAssignsChanged)
   return ContinueExiting;           
}         //End of CMainDialog::QuerySave&Exit()
   
       
//------------------------------------------------------------------------//
// OnSave
//
// Parameters   None
//
// Returns      Nothing   
//
// Called by    Windows through the message map when the user selects
//              File|Save from the main menu
//
// Remarks      Determines whether or not the Windows comm port assignments
//              have been modified and calls SaveSettings if so
//------------------------------------------------------------------------//
afx_msg void CMainDialog::OnSave()
{
   //
   //If the flag signals that a Windows comm port assignment was changed,
   //
   if (ComAssignsChanged == TRUE)
      {
       //
       //Call the SaveSettings function to save the settings in MCLIENT.INI
       //
       SaveSettings();
       
       //
       //Lower the flag to signal that no Windows comm port assignments
       //require saving at this time
       //
       ComAssignsChanged = FALSE;
      }
}


//------------------------------------------------------------------------//
// SaveSettings
//
// Parameters     None
//
// Returns        Nothing
//
// Called by      CMainDialog::OnSave
//                CMainDialog::OnCloseClick
//
// Remarks        Saves the Windows comm port assignments as specified by 
//                the Text members of the subclassed static controls pointed
//                to in the array CMainDialog::ComAssign[]. Assignments are
//                saved to the MCLIENT.INI file. 
//------------------------------------------------------------------------//
void CMainDialog::SaveSettings()
{
 int iloop;                     //Loop control variable
 char szCOMDest[10];            //Character string to hold "COMxDest"
 char szCOMIndex[3];            //Character string to hold comm port index
 char szServiceName[18];        //Character string to hold service name
                                //to which the comm port is attached  
 char szRedirPorts[18] = "";    //Character string holding list of comm port
                                //indices which are being redirected                                
 
 for (iloop=0; iloop<=8; iloop++)    //Iterate for each Windows comm port
    {
     strcpy(szCOMDest, "COM");       //Put "COM" in character string
     _itoa(iloop+1, szCOMIndex, 10); //Convert port index to character string 
     strcat(szCOMDest, szCOMIndex);  //Append port index to "COM" string
     strcat(szCOMDest, "Dest");      //Append to "COMx" string

     //
     //If the comm port assignment has been changed
     //
     if (ComAssign[iloop]->HasChanged == TRUE)
        {
         //
         //Set flag that the port assignment has been saved
         //
         ComAssign[iloop]->HasChanged == FALSE;
         
         //
         //Retrieve the character string of the MA+ service name to 
         //which this Windows comm port is assigned
         //
         ComAssign[iloop]->GetWindowText(szServiceName, 18);
     
         //
         //If the port assignment is "Local", then..
         //
         if (strcmp(szServiceName, "Local") == 0)
            {
             //
             //Clear any possible entry in the INI file
             //
             WritePrivateProfileString("Redirector", //[Redirector] section..
                                       szCOMDest,    //Make COMxDest entry
                                       "",           //Assign the null string
                                       lpszMCIniPath);//In [path] MCLIENT.INI
            }
         else //If the port assignment is not "Local", then..
            {
             //
             //Save this assignment into the MCLIENT.INI file 
             //
             WritePrivateProfileString("Redirector", //[Redirector] section..
                                       szCOMDest,    //Make COMxDest entry
                                       szServiceName,//This MA+ service
                                       lpszMCIniPath);  //[path] MCLIENT.INI 
         
             //
             //Append the RedirectPorts string with the comm port 
             //number and a ","
             //
             strcat(szRedirPorts, szCOMIndex);
             strcat(szRedirPorts, ",");
             } 
        }
        else //If the port assignment has not changed, then..
           {
            //
            //Check whether the port index should be in RedirectPorts 
            //
            ComAssign[iloop]->GetWindowText(szServiceName, 18);
            
            //
            //If the port assignment is not Local, then..
            //
            if (strcmp(szServiceName, "Local") != 0)
               {
                //
                //Append the RedirectPorts string with the comm port 
                //number and a ","
                //
                strcat(szRedirPorts, szCOMIndex);
                strcat(szRedirPorts, ",");
               } //end if not Local
            }    //end if assignment has not changed  

    }            //end iteration for each virtual com port 1 through 9
    
    //
    //If the new RedirectPorts string is not empty, then..
    if (szRedirPorts[0] != '\0')
       { 
        //
        //Clip off the trailing "," before writing
        //
        char* LastComma = strrchr(szRedirPorts, 0x2C);
        *LastComma = '\0';
       }
       
    //
    //Write to RedirectPorts section of MCLIENT.INI
    //
    WritePrivateProfileString("Redirector",
                              "RedirectPorts",
                              szRedirPorts,
                              lpszMCIniPath);
        
}                           
                
                                  
//------------------------------------------------------------------------//
// TSRLabel - is called if the MCLIENT.EXE TSR is loaded, in order to change
//       the "Client In Use..." label on the main dialog.
//------------------------------------------------------------------------//
void CMainDialog::TSRLabel ()
{
   CStatic* ClientInUse = (CStatic*) GetDlgItem(LBL_DLL); //Declare & assign
                                                          //pointer to label
   ClientInUse->SetWindowText("Client in use = TSR");     //Assign label text
}


//------------------------------------------------------------------------//
// LinesLabel - is called to show the number of active lines.
//------------------------------------------------------------------------//
void CMainDialog::LinesLabel ()
{
   CStatic* ActiveLines = (CStatic*) GetDlgItem(LBL_LINES);//Declare & assign
                                                           //pointer to label
   char szstring1[19] = "Active Lines = ";  //Prepare the text string
   char szstring2[4];                       //Declare array holding the 
                                            //number of lines   
   _itoa(NumLines, szstring2, 10);        //Convert number to character type
   strcat(szstring1, szstring2);          //Concatenate the strings
   ActiveLines->SetWindowText(szstring1); //Assign label text
}                        


//------------------------------------------------------------------------//
// ServersLabel - Displays label "No Active Servers" on the dialog
//------------------------------------------------------------------------//
void CMainDialog::ServersLabel ()
{                                         //Declare & assign pointer to label
   CStatic* ServersFound = (CStatic*) GetDlgItem(LBL_SERVERS); 
          
   ServersFound->SetWindowText("No Active Servers");    //Assign label text
}


//------------------------------------------------------------------------//
// GetComAssignRects
//
//
// Parameters 
//    ComIndex   integer representing the Windows comm port in which we are
//               interested. For each Windows comm port our dialog has a 
//               a static control for the comm port name and a static control
//               displaying which MA+ service name to which the comm port
//               is assigned. The static controls displaying the MA+ service
//               names have been subclassed and are referenced using an array 
//               of pointers to CDropStatic objects 
//
//    LeftRect   CRect structured variable to be filled with the dimensions
//               of the static control window displaying the particular
//               Windows comm port name
//
//   RightRect   CRect structured variable to be filled with the dimensions
//               of the static control displaying the MA+ service name to 
//               which this particular Windows comm port is assigned
//
//
// Returns       nothing. Purpose of this function is only to fill the 
//               rect parameter.
//
//
// Called by     CDragList::OnLButtonUp
//               CMainDialog::OnLButtonDblClk
//
// Remarks       This function fills the rect structure with the window 
//               dimensions of the static control pointed to by the index
//               contained in ComIndex. The dimensions are in relation to
//               the main dialog window attached to CMainDialog 
//------------------------------------------------------------------------//
void CMainDialog::GetComAssignRects(int ComIndex,
                                    CRect &LeftRect, CRect &RightRect)
{
   //
   //Fill the left CRect structure with the dimensions of the static 
   //control's window displaying the particular Windows comm port's name.
   //The ID of the static control can be derived by the ID of the first 
   //static control for the Windows comm ports names plus the ComIndex
   //parameter minus one (ComIndex ranges 0 through 8)
   //
   CWnd* pWnd = GetDlgItem(COM1_STATIC + ComIndex);
   
   //
   //Now get the window rectangle of this static control
   //
   pWnd->GetWindowRect(LeftRect);
   
   //
   //Fill the right CRect structure with the dimensions of the static 
   //control's window which displays the MA+ service name. This static 
   //control is subclassed and referenced through a array of pointers to
   //CDropStatic pointers
   //
   ComAssign[ComIndex]->GetWindowRect(RightRect); 
   
   //
   //Convert the rect dimensions, initially in screen coordinates, to 
   //coordinates in relation to the main dialog window
   //   
   ScreenToClient(LeftRect);
   ScreenToClient(RightRect);
}


//------------------------------------------------------------------------//
// SetComAssign 
//
//
// Parameters
//    ComIndex   integer representing the index into the array of CDropStatic 
//               pointers.  Each pointer in the ComAssign array points to 
//               a CDropStatic object attached to the static control which
//               displays the MA+ service name to which the particular 
//               Windows comm port is assigned.
//
//  Assignment   pointer to the character string containing the MA+ service
//               name to which the particular Windows comm port is to be 
//               assigned
//
//
// Returns       nothing
//
//
// Called by     CMainDialog::OnLButtonDblClk
//               CDragList::OnLButtonUp
//
// 
// Remarks       This function sets the window text of the static control
//               indexed by ComIndex, to the character string pointed to
//               by Assignment    
//------------------------------------------------------------------------//
void CMainDialog::SetComAssign(int ComIndex, const char* Assignment)
{
   //
   //Set the window text to the string pointed to by Assignment
   //
   ComAssign[ComIndex]->SetWindowText(Assignment);
   
   //
   //Raise flag that this comm port assignment was changed
   //
   ComAssign[ComIndex]->HasChanged = TRUE;
   
   //
   //Raise the flag to signal that at lease one Windows comm port assignment
   //was modified
   //
   ComAssignsChanged = TRUE;
}


//------------------------------------------------------------------------//
// CMainDialog::OnMouseMove ()
//
// PARMETERS   nFlags     Byte indicating which keys or buttons are 
//                        simultaneously pressed.
//            
//             point      CPoint denoting where in the client area the 
//                        mouse is located.
//
// RETURNS     nothing
//
// CALLED BY   Windows messaging mechanism.
//
// REMARKS     Used to diplay the status messages in the bottom frame of 
//             the dialog to prompt the user about possible interactions.
//
//------------------------------------------------------------------------//
afx_msg void CMainDialog::OnMouseMove (UINT nFlags, CPoint point)
{
   //
   //Convert point to screen coordinates
   //
   ClientToScreen (&point);
   
   //
   //If the mouse is within any of these rectangles, then set the 
   //status message
   //
   if (LinesRect.PtInRect (point) == TRUE) 
      {
       SetStatusBarText (IDS_LINES);
      }
   else if (GroupsRect.PtInRect (point) == TRUE)
      {
       SetStatusBarText (IDS_GROUPS);
      }
   else if (PortsRect.PtInRect (point) == TRUE)
      {
       SetStatusBarText (IDS_COMPORTS);
      }
   else if (ActiveServersRect.PtInRect (point) == TRUE)
      {
       SetStatusBarText (IDS_CURRENTSERVERS);
      } 
   else if (ActiveLinesRect.PtInRect (point) == TRUE)
      {
       SetStatusBarText (IDS_CURRENTLINES);
      } 
   else if (ClientInUseRect.PtInRect (point) == TRUE)
      {
       SetStatusBarText (IDS_CURRENTDRIVER);
      } 
           
}        


//------------------------------------------------------------------------//
// CMainDialog::SetStatusBarText ()
//
// PARAMETERS     nID      Numeric ID of the character string which forms
//                         the current status bar message
//
// RETURNS        nothing
//
// CALLED BY      CMainDialog::OnMouseMove ()
//
// REMARKS        Used to change the text of the current status bar message
//------------------------------------------------------------------------//
void CMainDialog::SetStatusBarText (int nID)
{
 CString szStatusBarText;  //Character string buffer to hold status bar text
 HFONT hStatusBarFont,     //Handle to the new font we want to use
       hOldFont;           //Handle to the current font of the device context
 CRect StatusBarRect;      //Rectangle of the status bar window
 
 //
 //Get a pointer to the status bar window
 //
 CWnd* pWndStatusBar = GetDlgItem (IDC_STATUSBAR);
 
 //
 //Get the dimensions of the status bar window
 //
 pWndStatusBar->GetClientRect (StatusBarRect);
 
 //
 //Now shrink the rectangle so the window borders don't get painted over
 //during the ExtTextOut () function
 StatusBarRect.InflateRect (-1, -1);

 //
 //Load the character string identified by nID
 //
 szStatusBarText.LoadString (nID);
 
 //
 //Get a device context for the status bar window
 //
 CClientDC DC (pWndStatusBar);
 
 //
 //Create the font
 //
 HDC hDC = DC.GetSafeHdc ();
 hStatusBarFont = ::CreateFont(HeightStatusBarFont,
                               0, 
                               0, 
                               0, 
                               400, 
                               0, 
                               0, 
                               0,
                               ANSI_CHARSET, 
                               OUT_DEFAULT_PRECIS, 
                               CLIP_DEFAULT_PRECIS,
                               DEFAULT_QUALITY, 
                               VARIABLE_PITCH | FF_SWISS, 
                               "Helv");  
 
 //
 //Select the status bar font into the device context
 //
 hOldFont = (HFONT) ::SelectObject ((HDC) (DC.GetSafeHdc ()), hStatusBarFont);
 
 //
 //Set the text color and the back color for the device context
 //
 DC.SetTextColor (::GetSysColor (COLOR_ACTIVECAPTION));
 DC.SetBkColor(::GetSysColor (COLOR_BTNFACE));
 
 //
 //Show the text
 //
 DC.ExtTextOut (15,
                5,
                ETO_CLIPPED | ETO_OPAQUE,
                StatusBarRect,
                szStatusBarText,
                szStatusBarText.GetLength (),
                NULL);
 
 //
 //Put the old font back in the device context
 //
 ::SelectObject(DC.GetSafeHdc (), hOldFont);
 
 //
 //Delete the font we created freeing GDI memory
 //
::DeleteObject (hStatusBarFont);  

} 


//------------------------------------------------------------------------//
// OnListServers - Function to respond to Options|List Servers menu item or 
//     clicking on the List Servers button from the dialog.
//------------------------------------------------------------------------//
afx_msg void CMainDialog::OnListServers ()
{
   EnableWindow(FALSE);                             //Disable main dialog
   ListServersDlg.ShowWindow(SW_SHOWNORMAL);        //Show the dialog
}


//------------------------------------------------------------------------//
// OnMoreDetail - Function to respond to the Options|More Detail menu item
//    or clicking on the More Detail button from the dialog
//------------------------------------------------------------------------//
afx_msg void CMainDialog::OnMoreDetail ()
{
   //
   //Assign all labels
   //
   MoreDetailDlg.SetLabels(); 
   
   EnableWindow(FALSE);                             //Disable main dialog
   MoreDetailDlg.ShowWindow(SW_SHOWNORMAL);         //Show the dialog
}


//------------------------------------------------------------------------//
// OnUsage - Function to respond to the Help|Usage menu item or clicking
//------------------------------------------------------------------------//
afx_msg void CMainDialog::OnUsage ()
{
  WinHelp(0L, HELP_CONTENTS);
}   


//------------------------------------------------------------------------//
// OnAbout - Function to respond to the Help|About menu item or clicking on
//           the About button from the dialog.
//------------------------------------------------------------------------//
afx_msg void CMainDialog::OnAbout ()
{
 CAboutDlg AboutDlg(this);
 AboutDlg.DoModal ();
}


//------------------------------------------------------------------------//
// FUNCTION        CMainDialog::OnInstallMACOMM ()
//
// PARAMETERS      none
//
// RETURNS         nothing
//
// CALLED BY       MFC when user clicks Install Driver button
//
// REMARKS         Puts "comm.drv=c:\windows\macomm.drv" in SYSTEM.INI
//                 and "CommDriver=old driver" in MCLIENT.INI
//------------------------------------------------------------------------//
afx_msg void CMainDialog::OnInstallMACOMM ()
{
 char szWinDir[144];
 
 //
 //Get the path to the Windows directory
 //
 GetWindowsDirectory(szWinDir, 144);
 
 //
 //Append "MACOMM.DRV" to Windows directory path name
 //
 strcat(szWinDir, "\\macomm.drv");
 
 //
 //Enter MACOMM.DRV in SYSTEM.INI
 //
 WritePrivateProfileString ("boot",
                            "comm.drv",
                            szWinDir,
                            "system.ini");

 //
 //If the old driver was comm.drv then change it to mscomm.drv
 //
 if (PresentCommDriver == "comm.drv")
    {
     PresentCommDriver = "mscomm.drv";
    } 

 //
 //Enter the old driver name in the MCLIENT.INI
 //
 WritePrivateProfileString ("Redirector",
                            "CommDriver",
                            PresentCommDriver,
                            lpszMCIniPath);
                            
 //
 //Ask for "Reboot windows?"
 //
 int Response = 
 MessageBox(RESTART_WINDOWS, APP_TITLE, MB_ICONQUESTION|MB_YESNO);
          
 //
 //If response was Yes to reboot windows, then reboot windows
 //
 if (Response == IDYES)
    {
     ExitWindows(EW_RESTARTWINDOWS, 0); 
    }
 else   //Just quit Port Status & Setup
    {
     SendMessage (WM_CLOSE);
    }   
                             
}//End  afx_msg void CMainDialog::OnInstallMACOMM () 


//------------------------------------------------------------------------//
// FUNCTION        CMainDialog::OnOK ()
//------------------------------------------------------------------------//
void CMainDialog::OnOK ()
{
 SendMessage (WM_CLOSE);
}

void CMainDialog::OnCancel ()
{
 SendMessage (WM_CLOSE);
}  
  
afx_msg void CMainDialog::OnExitClick ()
{
 SendMessage (WM_CLOSE);
}


//------------------------------------------------------------------------//
// FUNCTION        CMainDialog::OnClose ()
//------------------------------------------------------------------------//
afx_msg void CMainDialog::OnClose ()           //Close the application
{
   //
   //If QuerySave&Exit signals to continue with exit procedure
   //
   if (QuerySaveAndExit() == TRUE)                                
      {                        
       //
       //Destroy all dialog windows including this one
       //
       ListServersDlg.DestroyWindow(); //Destroy the List Servers dialog
       MoreDetailDlg.DestroyWindow();  //Destroy the More Details dialog
       DestroyWindow ();               //Sends WM_DESTROY and WM_NCDESTROY
      } 
}

 
afx_msg void CMainDialog::OnDestroy () //Close the application
{
  CDialog::OnDestroy ();               //Call the ancestor for completeness
  ::PostQuitMessage (0);               //Let Windows know we are quitting
}

 
/////////////////////////////////////////////////////////////////////////////
// FUNCTION:   CMainDialog::PostNcDestroy ()                              //
// PARAMETERS: none                                                      //
// RETURNS:    nothing                                                  //
// REMARKS:    Called by CWnd::OnNcDestroy ()                          //
////////////////////////////////////////////////////////////////////////
void CMainDialog::PostNcDestroy ()
{
   //CDialog::PostNcDestroy ();     //Ancestor function is virtual, don't call
   BackgroundBrush.DeleteObject (); //Delete the GDI object attached to brush
   delete this;                     //Free heap of this memory
}

