//========================================================================//
// MASSIST.CPP : C++ source code for those functions of the Port Status   //
//               & Setup program which call to Modem Assist's MCLIENT.DLL //
//               or MCLIENT.TSR. See PORTSETC.DEF for more info.          //
// Remarks     : Compiled under the large memory model.                   //
// History     : 05/28/95 Original version                                //
//                                                                        //
// Written By  : George Cross                                             //
// Copyright (c) Synergy Solutions Inc,1 2150 S Country Club, Mesa, AZ    // 
//========================================================================//

#include <afxwin.h>        //MFC header file - all MFC apps must use
#include <string.h>        //C library header for string functions
#include <dos.h>           //C library header for memory addressing macros
#include "massist.h"       //This module's header for type definitions
#include "maindlg.h"       //Header for the main dialog class declarations
#include "messages.h"      //Header containing all string constants
#include "portsetc.rh"     //Header containing resource identifiers


//========================================================================//
// Global variables and functions...                                      //
//========================================================================//

extern HINSTANCE  hinstMClient;         //Handle to MCLIENT.DLL

extern char __far lpszMCIniPath[60];    //File path to MCLIENT.INI file
extern char __far ClientConValues[51];  //Buffer containing CLIENT.CON values 


//------------------------------------------------------------------------//
// Below we declare and initialize a register structure variable, which   //
// will be initialized once again and passed to the function CMApiCall    //
// in MCLIENT.DLL.  CMApiCall is called in the function GetNamesDLL below.//
//------------------------------------------------------------------------//
RCALLSTRUCT  RStruct = {0L,0L,0L,0L,0L,0L,0L,0L,0,0,0,0,0,0,0,0,0};


//========================================================================//
// The CLineInfo class to hold MA+ Server, Group, and Line information.  A 
// variable of this type is passed, by reference to either CMApiCall 
// function in MCLIENT.DLL or function AH=10h in MCLIENT.EXE in order to
// retrieve MA+ Server, Group and Line names.
//========================================================================//

//------------------------------------------------------------------------//
// Constructor for the CLineInfo class                                    //
//------------------------------------------------------------------------//
CLineInfo::CLineInfo ()
{               
    LenReplyBuffer = 50;    // 16 bytes each for Server, Group and Line
                            // name and 2 bytes for Line Status 
    _fmemset (ServerName,   // add 48 '?'s as wildcard for service name
              '?', 
              48); 

    Status = AVAIL;         // initialize Status - not imperative..
}


//========================================================================//
// Modem Assist calling functions of CMainDialog class.
//
//
// LoadMClientDLL - In this function, we load MCLIENT.DLL
//------------------------------------------------------------------------// 
BOOL CMainDialog::LoadMClientDLL()
{
   char szstring[60], szMessage[100], szhinstError[6];
  
   //--------------------------------------------------------------------//
   // Below we find the path to MCLIENT.DLL as written in MCLIENT.INI 
   //--------------------------------------------------------------------//
   GetPrivateProfileString("Redirector","ClientDLL","MCLIENT.DLL",
                           szstring, sizeof(szstring), lpszMCIniPath);         
 
   //--------------------------------------------------------------------//
   // Below we load the MCLIENT.DLL, and immediately abort if unsuccessful 
   //--------------------------------------------------------------------//       
   hinstMClient = LoadLibrary(szstring);

   if (hinstMClient <= HINSTANCE_ERROR)
      {
       strcpy(szMessage, MCLIENTDLL_LOAD_ERROR);
       strcat(szMessage, szstring);
       _itoa((int) hinstMClient, szhinstError, 10);
       strcat(szMessage, "\nError number: ");
       strcat(szMessage, szhinstError);
       MessageBox(szMessage, APP_TITLE, MB_ICONSTOP);
       return FALSE;
      } 
   return TRUE;
}


//------------------------------------------------------------------------//
// GetNamesDLL - In this function we make a call to the MCLIENT.DLL to 
//               retrieve the service names provided by Modem Assist.
//------------------------------------------------------------------------// 
BOOL CMainDialog::GetNamesDLL ()
{
   int ServerFlag, GroupFlag, LineFlag;  //Flags to show a unique name 
                                         //was found
   int xvalue, ccode;                    //Multipurpose return values
   int iloop;                            //Loop control variable 
   char szstring[40];          //General purose holding area for char strings 
     
   //---------------------------------------------------------------------//
   // Below we declare a pointer to the CMApiCall function                   
   //---------------------------------------------------------------------//
   int (__far __pascal* lpfnCMApiCall) (RCALLSTRUCT __far* lpRStruct);
  
   //--------------------------------------------------------------------//
   // Below we clear the general purpose character string buffer
   //--------------------------------------------------------------------//
   strncpy(szstring, " ", 40);

   //---------------------------------------------------------------------//
   // Locate the address of CMApiCall function, ordinal 1, in MCLIENT.DLL.
   // All typecasts are most necessary in GetProcAddress call for strict 
   // type checking.  GetProcAddress returns FARPROC and we must typecast
   // it to a pointer to the function of the type we have declared for 
   // the function CMApiCall. The second parameter in GetProcAddress must
   // be a LPCSTR containing the function ordinal number in the low word. 
   //---------------------------------------------------------------------// 
   lpfnCMApiCall= (int (__far __pascal*) (RCALLSTRUCT __far*))
   
                   GetProcAddress(hinstMClient,        //Handle to MCLIENT.DLL
                                 (LPCSTR) MAKELP(0,1));//Far character pointer
                                                       //indicating ordinal
                                                       //function #1

   if (lpfnCMApiCall == NULL)   //If the CMApiCall fn was not located..
      {
       MessageBox(CMAPICALL_ADDRESS_ERROR "\n" CONTACT_TECH,
                  APP_TITLE,
                  MB_ICONSTOP);
       FreeLibrary(hinstMClient);  //Unload MCLIENT.DLL 
       return FALSE;               //Abort this function
      }
                        
   //---------------------------------------------------------------------//
   // Below we call the call PrepareRMCS function to fill the register 
   // structure variable
   //---------------------------------------------------------------------//
   PrepareRMCS(&RStruct,   //Pointer to register structure
               0);         //Subfunction 0h indicating first call to
                           //the Query Service Names function (AH=10h)
 
   //---------------------------------------------------------------------//
   // Below we call the CMApiCall function to retrieve the names of the 
   // services provided by Modem Assist Plus on the network...
   //---------------------------------------------------------------------//
   (*lpfnCMApiCall) (&RStruct);        //Call CMApiCall()
                                        
   ccode = ((WORD) RStruct.EAX) >> 8;  //Result is in AH so move it to ccode  
   
   //---------------------------------------------------------------------//
   // Below we clear the general purpose character string buffer
   //---------------------------------------------------------------------//
   strncpy(szstring, " ", 40);

   //---------------------------------------------------------------------//
   // Below we check that a Modem Assist service was retrieved.
   // If so, then we add the information to the appropriate list boxes...
   //---------------------------------------------------------------------// 
   switch (ccode)
   {
   case 0:                          //MA+ service was retrieved and more exist
      NumLines = NumLines + 1;      //Increment the Lines count
      AddLineAndStatus(szstring);   //Append the Status to the Line name
      Lines->AddString(szstring);   //Put the Line name & Status in list
      strncpy(szstring, " ", 40);   //Clear the character string buffer
                                        
      Groups->AddString                    //Add the new Group name to list
             (strncpy(szstring,            //Holding area for strings
                      LineInfo.GroupName,  //Beginning of name
                      16));                //16 characters max 
      strncpy(szstring, " ", 40);       //Clear the character string buffer
    
      ListServersDlg.AddServerName                 //Add Server name to list
                     (strncpy(szstring,            //String holding area
                              LineInfo.ServerName, //Beginning of Server name
                              16));                //Max length 16 characters
      strncpy(szstring, " ", 40);             //Clear the character string

      //------------------------------------------------------------------//
      // Below we continually query Modem Assist services by calling
      // the MODEMASSISTCALL function in search of other Lines, Groups
      // or Servers.
      // We terminate the loop when no other services are to be found.
      // That is, when ccode==0.
      //------------------------------------------------------------------//  
      do
         {
         ServerFlag = GroupFlag = LineFlag = FALSE;  //Initialize flags

         //---------------------------------------------------------------//
         // Call the PrepareRMCS function to initialize the members of
         // the register structured variable.
         //---------------------------------------------------------------//
         PrepareRMCS(&RStruct,       //Pointer to register structure
                     1);             //Subfunction 1 indicating a subsequent
                      //call to Query Service Names function
                             
         ccode = (*lpfnCMApiCall)(&RStruct);  //Call CMAPICall 
         ccode = ((WORD) RStruct.EAX) >> 8;   //Move result into AH 

         switch (ccode)
         {
         case 0:                //An MA+ service was found and more exist
         case 1:                //An MA+ service was found and no more exist
            //-----------------------------------------------------------//
            // Below we compare the new Server name returned with all other 
            // Server names already listed in the Server list box.
            // If the new Server name already exists, we set the flag
            // and immediately break the loop...
            //-----------------------------------------------------------//             
            for (iloop=0;iloop<ListServersDlg.GetCount();++iloop)//Traverse
              {                                                  //list
                ListServersDlg.GetText(iloop, szstring);//Get an old name 
                xvalue = _strnicmp(LineInfo.ServerName, //Compare the new name
                                   szstring,            //to the old name
                                   16);                 //Max 16 characters
                if (xvalue == 0)        //If the names are equivalent..
                   {                       
                    ServerFlag = TRUE;  //Indicate the new name is not unique
                    break;              //Break the loop. Stop comparing
                   }
              }    
            strncpy(szstring, " ", 40); //Clear the string holding area
                                          
            //------------------------------------------------------------//
            // Below we compare the new Group name returned with all other 
            // Group names already listed in the Group list box.
            // If the new Group name already exists, we set the flag
            // and immediately break the loop...
            //------------------------------------------------------------//             
            for (iloop=0; iloop<Groups->GetCount(); ++iloop)//traverse list
               {
                Groups->GetText(iloop, szstring);      //Retrieve old name
                xvalue = _strnicmp(LineInfo.GroupName, //Compare new name..
                                   szstring,           //to old name 
                                   16);                //Max 16 characters                
                if (xvalue == 0)           //If the names do match..
                  { 
                   GroupFlag = TRUE;      //Raise flag indicating new Group
                                     //name is NOT unique 
                   break;                 //Break out of loop. Stop comparing
                  }
               }                          //End of For loop
            strncpy(szstring, " ", 40);   //Clear general use string buffer
              
            //------------------------------------------------------------//
            // Below we compare the new Line name returned with all other
            // Line names already listed in the Line list box. 
            // Same as we did for the Groups...
            //------------------------------------------------------------//
            for (iloop=0; iloop<Lines->GetCount(); ++iloop) //traverse list
               {
                Lines->GetText(iloop, szstring);       //Retrieve old name
                xvalue = _strnicmp(LineInfo.LineName,  //Compare new name..
                                   szstring,           //to old name
                                   16);                //Max 16 characters                       
                if (xvalue == 0)          //If the names do match..
                   { 
                    LineFlag = TRUE;      //Raise flag indicating new Group
                                          //name is NOT unique 
                    break;                //Break out of loop. Stop comparing
                   }
               }                          //End of For loop
            strncpy(szstring, " ", 40);   //Clear general use string buffer
          
            if (!ServerFlag)              //If the new Server name is unique
               {
                ListServersDlg.AddServerName           //Add it to the list
                               (strncpy(szstring,      //String buffer
                                LineInfo.ServerName,   //Start of Server name
                                16));                  //16 characters max
                strncpy(szstring, " ", 40);  //Clear the string holding area
               }

            if (!GroupFlag)               //If the Group name is unique..
               {
                Groups->AddString          //Add the new Group name to list
                 (strncpy(szstring,       //Holding area for strings
                         LineInfo.GroupName,     //Beginning of name
                  16));                   //16 characters max 
                   
                strncpy(szstring, " ", 40);          //Clear string buffer
               }
       
            if (!LineFlag)                  //If the Line name is unique..
             {
              NumLines = NumLines + 1;    //Increment the Lines count
              AddLineAndStatus(szstring); //Append the Status to the name
                  Lines->AddString(szstring); //Add the new Line name to the
                                  //list
                  strncpy(szstring, " ", 40); //Clear string buffer
                 }                            
         break;                //Case ccode==0: or ccode==1:

         case 3:            //An invalid request was made to CMApiCall
            MessageBox(INVALID_REQUEST "\n" CONTACT_TECH,
                       APP_TITLE,
                       MB_ICONSTOP);
            return FALSE;
         break; 
         
         case 6:               //There was a resource or buffer shortage
            MessageBox(RESOURCE_SHORTAGE, 
                       APP_TITLE,
                       MB_ICONSTOP);
            return FALSE;
         break;                //Case ccode==6:
         
         default:              //CMApiCall returned neither 0,1,3 nor 6
            MessageBox(UNKNOWN_RESPONSE "\n" CONTACT_TECH, 
                       APP_TITLE,
                       MB_ICONSTOP);
            return FALSE;
         break;                //Case ccode==other value
        }                      //End of switch statement
                   
        } while (ccode == 0);                 //End of Do loop
   break;                                     //Break the Case 0 statement
 
   //---------------------------------------------------------------------//
   // Below we handle the case that no Modem Assist service was found,
   // simply printing a message to that effect.
   //---------------------------------------------------------------------//   
   case 1:               //No MA+ service was retrieved and no others exist
       MessageBox(ZERO_ACTIVE_SERVERS, APP_TITLE);
       ServersLabel();              //Display zero active servers found
   break;                             //Break the Case 1 statment                          
    
   //---------------------------------------------------------------------//
   // Below we handle the cases that we made an invalid request (ccode==3)
   // or that there was a resource/buffer shortage (ccode==6) from our
   // call to MODEMASSISTCALL.  We must not create the dialog box if so...
   //---------------------------------------------------------------------// 
   case 3:   //An invalid request was made to CMApiCall
       MessageBox(INVALID_REQUEST "\n" CONTACT_TECH, 
                  APP_TITLE,
                  MB_ICONSTOP);
       return FALSE;
   break;
   
   case 6:               //There was a resource or buffer shortage
       MessageBox(RESOURCE_SHORTAGE, 
                  APP_TITLE,
                  MB_ICONSTOP);
       return FALSE;
   break;
   
   default:              //CMApiCall returned neither 0,1,3 nor 6
       MessageBox(UNKNOWN_RESPONSE "\n" CONTACT_TECH, 
                  APP_TITLE,
                  MB_ICONSTOP);
       return FALSE;
  }                                        //End of the Switch statement
           
  return TRUE;
}                                          //Search was successful


//------------------------------------------------------------------------//
// PrepareRMCS - In this function we fill a few registers in the real mode
//               call structure appropriately before calling CMApiCall 
//               function with AH=10h in the MCLIENT.DLL 
// Parameters  - pRCallStruct - a pointer to register structure variable
//             - Subfunction - either 0 if this is the first call to Query 
//          Service Names, or 1 if it is a subsequent call
//------------------------------------------------------------------------//
void CMainDialog::PrepareRMCS(RCALLSTRUCT* pRCallStruct,  
                              int Subfunction)
{
   void __far* lpvLineInfo;               //Declare a void pointer
   const int Function = 0x10;             //AH=10h in Query Service Names
                                          //function of MA+ API
   lpvLineInfo = (void __far*) &LineInfo; //Assign it to address of LineInfo

   pRCallStruct->EAX = Function * 0x100;   //Put Function in AH
   pRCallStruct->EDX = 0xffff;             //Set DX to -1. Necessary for call
                                           //to Query Service Names function
   pRCallStruct->ES = _FP_SEG(lpvLineInfo);  //Put segment of LineInfo in ES
   pRCallStruct->EDI = _FP_OFF(lpvLineInfo); //Put offset of LineInfo in DI
   pRCallStruct->ECX = Subfunction;          //Put Subfunction in CL (=0 or 1)
}


//------------------------------------------------------------------------//
// GetNamesTSR - In this function we make a call to MCLIENT.EXE to with 
//               AH=10h to retrieve the service names provided by MA+.
//------------------------------------------------------------------------//
BOOL CMainDialog::GetNamesTSR ()
{
   int ServerFlag, GroupFlag, LineFlag;    //Flags to show a unique name
                                           //was found
   int xvalue, ccode;                      //Multipurpose return values
   int iloop;                            //Loop control variable
   char szstring[40];      //General purose holding area for char strings 

   //---------------------------------------------------------------------//
   // Below we declare the RMCall function                   
   //---------------------------------------------------------------------//
   extern int RMCall (int Function, int Subfunction,
                      void __far* lpLineInfo, int LenCLInfo);

   //---------------------------------------------------------------------//
   // Below we clear the general purpose character string buffer
   //---------------------------------------------------------------------//
    strncpy(szstring, " ", 40);
 
   //---------------------------------------------------------------------//
   // Below we call the RMCall function to retrieve the names of the 
   // services provided by Modem Assist Plus on the network...
   //---------------------------------------------------------------------//
   ccode = RMCall (0x10,              //AH=10h for Query Service Names 
                   0,                 //CL=0 for search first
                   &LineInfo,         //Address of pattern/reply buffer
                   sizeof(LineInfo)); //Length of buffer
 
   //---------------------------------------------------------------------//
   // Below we clear the temporary buffer
   //---------------------------------------------------------------------//
   strncpy(szstring, " ", 40);

   //---------------------------------------------------------------------//
   // Below we check that a Modem Assist service was found.
   // If so, then we add the information to the appropriate list boxes...
   //---------------------------------------------------------------------// 
   switch (ccode)                   
   {
   case 0:                          //MA+ service was retrieved and more exist
      NumLines = NumLines + 1;      //Increment the Lines count
      AddLineAndStatus(szstring);   //Append the Status to the Line name
      Lines->AddString(szstring);   //Put the Line name & Status in list
      strncpy(szstring, " ", 40);   //Clear the character string buffer

      Groups->AddString                     //Add the Group name to the list
             (strncpy(szstring,            //Holding area for strings
                      LineInfo.GroupName,  //Beginning of Group name
                      16));                //Max length is 16 characters
      strncpy(szstring, " ", 40);           //Clear the character string

      ListServersDlg.AddServerName                //Add Server name to list
                     (strncpy(szstring,           //String holding area
                              LineInfo.ServerName,//Beginning of Server name
                              16));               //Max length 16 characters
      strncpy(szstring, " ", 40);            //Clear the character string

      //------------------------------------------------------------------//
      // Below we continually query Modem Assist services by calling
      // the MODEMASSISTCALL function in search of other Lines, Groups
      // or Servers.
      // We terminate the loop when no other services are to be found.
      // That is, when ccode==0.
      //------------------------------------------------------------------//  
      do
         {
          ServerFlag = GroupFlag = LineFlag = FALSE; //initialize flags

          ccode =       RMCall (0x10,             //AH=10h for Query Service
                                1,                //CL=1 for search next
                                &LineInfo,        //Address of pattern buffer
                                sizeof(LineInfo));//Length of pattern buffer  

          switch (ccode)
          {
          case 0:               //An MA+ service was found and more exist
          case 1:               //An MA+ service was found and no more exist
            //-----------------------------------------------------------//
             // Below we compare the new Server name returned with all other 
             // Server names already listed in the Server list box.
             // If the new Server name already exists, we set the flag
             // and immediately break the loop...
             //-----------------------------------------------------------//             
             for (iloop=0;iloop<ListServersDlg.GetCount();++iloop)//Traverse
               {                                                  //list
                ListServersDlg.GetText(iloop,szstring);//Get an old name 
                xvalue = _strnicmp(LineInfo.ServerName,//Compare the new name
                                   szstring,           //to the old name
                                   16);                //Max 16 characters
                if (xvalue == 0)        //If the names are equivalent..
                   {                       
                    ServerFlag = TRUE;  //Indicate the new name is not unique
                    break;              //Break the loop. Stop comparing
                   }
               }
             strncpy(szstring, " ", 40); //Clear the string holding area
                                          
             //-----------------------------------------------------------//
             // Below we compare the new Group name returned with all other 
             // Group names already listed in the Group list box.
             // If the new Group name already exists, we set the flag
             // and immediately break the loop...
             //-----------------------------------------------------------//             
             for (iloop=0; iloop<Groups->GetCount(); ++iloop) //Traverse list
               {
                Groups->GetText(iloop, szstring);      //Get an old name 
                xvalue = _strnicmp(LineInfo.GroupName, //Compare the new name
                                   szstring,           //to the old name
                                   16);                //Max 16 characters
                if (xvalue == 0)        //If the names are equivalent..
                   {                       
                    GroupFlag = TRUE;   //Indicate the new name is not unique
                    break;              //Break the loop. Stop comparing
                   }
               }
             strncpy(szstring, " ", 40); //Clear the string holding area
                                          
              
             //-----------------------------------------------------------//
             // Below we compare the new Line name returned with all other
             // Line names already listed in the Line list box. 
             // Same as we did for the Groups...
             //-----------------------------------------------------------//
             for (iloop=0; iloop<Lines->GetCount(); ++iloop) //Traverse list
                {
                 Lines->GetText(iloop, szstring);      //Get an old name
                 xvalue = _strnicmp(LineInfo.LineName, //Compare the new name
                                    szstring,          //to the old name
                                    16);               //Maximum 16 character                        
                 if (xvalue == 0)       //If the strings are equivalent
                    {
                     LineFlag = TRUE;   //Indicate the new name is NOT unique
                     break;             //Break the loop. Stop comparing
                    }
                }
             strncpy(szstring, " ", 40);  //Clear the string holding area
          
             if (!ServerFlag)              //If the new Server name is unique
                {
                 ListServersDlg.AddServerName         //Add it to the list
                                (strncpy(szstring,    //String buffer
                                LineInfo.ServerName,  //Start of Server name
                                16));                 //16 characters max
                 strncpy(szstring, " ", 40);  //Clear the string holding area
                }
       
             if (!GroupFlag)              //If the new Group name is unique
                {
                 Groups->AddString                    //Add it to the list
                         (strncpy(szstring,           //String buffer
                          LineInfo.GroupName,         //Start of Group name
                          16));                       //16 characters max
                 strncpy(szstring, " ", 40);  //Clear the string holding area
                }
       
             if (!LineFlag)               //If the new Line name is unique
                {
                 NumLines = NumLines + 1;     //Increment the Lines count
                 AddLineAndStatus(szstring);  //Add Status to the Line name
                 Lines->AddString(szstring);  //Append Line name to list
                 strncpy(szstring, " ", 40);  //Clear the string holding area
                }
          break;                //End of if case ccode==0 or 1 

          case 3:               //An invalid request was made to CMApiCall
             MessageBox(INVALID_REQUEST "\n" CONTACT_TECH, 
                        APP_TITLE,
                        MB_ICONSTOP);
             return FALSE;
          break;                //Case ccode==3
          
          case 6:               //There was a resource or buffer shortage
             MessageBox(RESOURCE_SHORTAGE, 
                        APP_TITLE,
                        MB_ICONSTOP);
             return FALSE;
          break;                //Case ccode==6:
          
          default:              //CMApiCall returned neither 0,1,3 nor 6
             MessageBox(UNKNOWN_RESPONSE "\n" CONTACT_TECH, 
                        APP_TITLE,
                        MB_ICONSTOP);
             return FALSE;
          break;                //Case ccode==other value
         }                      //End of switch statement
                   
         } while (ccode == 0);            //End of do loop
   break;                                 //Break from case 0
 
      //------------------------------------------------------------------//
      // Below we handle the case that no Modem Assist service was found,
      // simply printing a message to that effect.
      //------------------------------------------------------------------//   
   case 1:                      //No MA+ service retrieved and no more exist
      MessageBox(ZERO_ACTIVE_SERVERS, 
                 APP_TITLE,
                 MB_ICONSTOP);
      ServersLabel();            //Display zero active servers found
   break;                                                              
    
      //------------------------------------------------------------------//
      // Below we handle the case that we made an invalid request (ccode==3)
      // or that there was a resource/buffer shortage (ccode==6) from our
      // call to RMCALL.  We must not create the dialog box if so...
      //------------------------------------------------------------------// 
   case 3:   //An invalid request was made to RMCall
      MessageBox(INVALID_REQUEST "\n" CONTACT_TECH, 
                 APP_TITLE,
                 MB_ICONSTOP);
      return FALSE;
   break;
   
   case 6:               //There was a resource or buffer shortage
      MessageBox(RESOURCE_SHORTAGE, 
                 APP_TITLE,
                 MB_ICONSTOP);
      return FALSE;
   break;
   
   default:              //CMApiCall returned neither 0,1,3 nor 6
       MessageBox(UNKNOWN_RESPONSE "\n" CONTACT_TECH, 
                  APP_TITLE,
                  MB_ICONSTOP);
       return FALSE;
   }                                   //End of the Switch statement
           
    return TRUE;                       //Search was successful
}                                      //End of GetNamesTSR   
  
  
//------------------------------------------------------------------------//
// AddLineAndStatus - appends a character string indicating the status of 
//        the MA+ service, to the character string depicting the
//        the Line name of the service.
// Parameters       - szstring: a character string containing the Line name. 
//------------------------------------------------------------------------//
void CMainDialog::AddLineAndStatus (char* szstring)
{
   //---------------------------------------------------------------------//
   // Below we the determine Status of the Line. The Status of the Line
   // is returned in the very last byte of the CLineInfo structure.
   //---------------------------------------------------------------------//
   char szStatus[8];
    
   switch (LineInfo.Status/0x100)
      {
       case AVAIL: 
          strcpy(szStatus, "AVAIL");
       break;
       case OUT:
          strcpy(szStatus, "OUT");
       break;
       case INUSE:
          strcpy(szStatus, "INUSE");
       break;
       default:
          strcpy(szStatus, "UNKNOWN");
       break;
      }
    
   //-----------------------------------------------------------------
   // Below we create the entry to the Line listbox 
   //-----------------------------------------------------------------
   strcpy(szstring, LineInfo.LineName);   //Move Line name to string buffer
   strcat(szstring, "\t");                //Append a tab character
   strcat(szstring, szStatus);            //Append the Status
}


//------------------------------------------------------------------------//
// CMainDialog::ReadMClientINI()
//
// Parameters       None
//
// Returns          TRUE if function was successful. FALSE if the function
//                  could not find the function GetClientConValues() in 
//                  PORTSET.DLL.
//
// Called By        CMainDialog::GetMAValues()
//
// Remarks          This function also reads values from the CLIENT.CON
//                  file.  This path to this file is found in MCLIENT.INI
//                  [ClientParms] section, "FileName" entry.
//
//            ***** PLEASE SEE PORTSET.DLL source file GETCLIEN.C for 
//                  documentation on the function GetClientConValues().
//------------------------------------------------------------------------//
int CMainDialog::ReadMClientINI ()
{
 int xvalue;                    //General purpose function return code
 int iloop;                     //Loop control variable
 char szCOMDest[10] = "COM";    //Character string to hold "COMxDest"
 char szCOMIndex[3];            //Character string to hold comm port index
 char szServiceName[18];        //Character string to hold service name
                                //to which the comm port is attached
 char szRedirectPorts[19];      //Character string to hold RedirectPorts stmt

 //
 //Declare the GetClientConValues function
 //
 extern int GetClientConValues (char __far* ClientConValues,
                                char __far* lpszMCIniPath); 
 
 //
 //Call GetClientConValues()
 //
 GetClientConValues (ClientConValues, lpszMCIniPath);
                                   
 //
 //Get the RedirectPorts statement
 //
 GetPrivateProfileString("Redirector",    //[Redirector] section
                         "RedirectPorts", //RedirectPorts statement
                         "",              //Default return string
                         szRedirectPorts, //Buffer to hold string
                         19,              //Length of buffer
                         lpszMCIniPath);  // [path]MClient.INI
         
 for (iloop=0; iloop<=8; iloop++)     //Iterate for each Windows comm port
    {
     _itoa(iloop + 1, szCOMIndex, 10);//Convert port index to character string 
     strcat(szCOMDest, szCOMIndex);   //Append port index to "COM" string
     strcat(szCOMDest, "Dest");       //Append to "COMx" string

     xvalue = 
     GetPrivateProfileString("Redirector",  //Look in [Redirector] section..
             szCOMDest,                     //for COMxDest entry
             "",                            //Default comm port assignment
             szServiceName,                 //Buffer to receive service name
             18,                            //Length of receive buffer
             lpszMCIniPath);                //Full path name of MCLIENT.INI
     
     //
     //If the setting is NULL then..
     // 
     if (xvalue == 0) 
        {
         //
         //Check to see if this comm port is in the RedirectPorts statement
         //
         xvalue = strspn(szCOMIndex, szRedirectPorts);
         
         //
         //If this comm port is in the RedirectPorts statement, then
         //
         if (xvalue != 0)
            {
             //
             //Assign this comm port the default Connect Destination 
             //from the CLIENT.CON file
             //
             //This value will be located at the 34th byte of the 
             //ClientConValues[] character array
             //
             strcpy(szServiceName, ClientConValues + 34);
             
             //
             //Write this destination MA+ service name as the assignment
             //for this comm port in "ComXDest" statement of MCLIENT.INI
             //  
             WritePrivateProfileString("Redirector",   //[Redirector] section
                                       szCOMDest,      //COMxDest statement
                                       szServiceName,  //default MA+ dest
                                       lpszMCIniPath); // [path] MCLIENT.INI
            } 
         else //Else if this comm port is not in the RedirectPorts statement
            {
             //
             //Assign this comm port as "Local". Not redirected.
             //                               
             strcpy(szServiceName, "Local");
            } 
        } //End if (xvalue == 0). This comm port is not redirected.

     //
     //Set the window text for the static control displaying the MA+
     //service name to which the particular Windows comm port is assigned
     //
     ComAssign[iloop]->SetWindowText(szServiceName);
     
     strcpy(szCOMDest, "COM"); //Reset the character string holding COMxDest 
    } //End for (iloop=0; iloop<=8; iloop++). Iterate for each Windows port 

 return TRUE;
} //End CMainDialog::ReadMClientINI


//------------------------------------------------------------------------//
// FUNCTION        CMainDialog::CheckForMACOMMDRV()
//
// PARAMETERS      none
//
// RETURNS         nothing
//
// CALLED BY       CMainDialog::CMainDialog ()
//
// REMARKS         Used to check for the entry COMM.DRV=MACOMM.DRV in the 
//                 SYSTEM.INI file.
//------------------------------------------------------------------------//
void CMainDialog::CheckForMACOMMDRV ()
{
 CWnd* pWnd;
 char szPresentCommDriver[60];  

 //
 //Get the file name to the current comm driver in use
 //
 GetPrivateProfileString ("boot",             //[boot] section
                          "comm.drv",         //"comm.drv=" statement
                          "",                 //default string
                          szPresentCommDriver,//Buffer to hold file name
                          60,                 //Size of Buffer
                          "system.ini");      //Look in SYSTEM.INI

 //
 //Convert to CString object
 //
 PresentCommDriver = szPresentCommDriver;
 
 //
 //Convert the character string to upper case
 //
 PresentCommDriver.MakeLower ();
 
 //
 //If "macomm.drv" is a subset of the file name of the current driver...
 //
 if (PresentCommDriver.Find ("macomm.drv") == -1)
    {
     //
     //Iterate for each virtual Windows comm port
     //
     for (int ComIndex=0; ComIndex<=8; ComIndex++)  
        { 
         //
         //Get a pointer to the static control for the com port name
         //
         pWnd = GetDlgItem (COM1_STATIC + ComIndex);
         
         //
         //Hide the windows for both the com port name and assignment
         //
         pWnd->ShowWindow (SW_HIDE);
         ComAssign[ComIndex]->ShowWindow (SW_HIDE);
         
        }//End  for (int ComIndex=0; ComIndex<=8; ComIndex++)   
     //
     //Show the "Install MACOMM.DRV" button and static window
     //
     pWnd = GetDlgItem (IDC_MACOMMDRV);
     pWnd->ShowWindow (SW_SHOW);
     pWnd = GetDlgItem (IDC_MACOMMINSTALL);
     pWnd->ShowWindow (SW_SHOW);
         
    }//End  if (PresentCommDriver.Find ("MACOMM.DRV") == -1)       
}//End  void CMainDialog::CheckForMACOMMDRV ()   

                  