//========================================================================//
// MSGWND.CPP : C++ source code for the initial non-user-controllable     //
//              window of the Port Status & Setup program. See            //
//              PORTSETC.DEF for more info                                //
// Remarks     : Compiled under the large memory model.                   //
// History     : 06/30/95 Original version                                //
//                                                                        //
// Written By  : George Cross                                             //
// Copyright (c) Synergy Solutions Inc,1 2150 S Country Club, Mesa, AZ    // 
//========================================================================//

#include "msgwnd.h"        //This module's header for type definitions

//========================================================================//
// Class CMessageWnd 
// 
// Derived From       CFrameWnd
//
// Member Functions   
//       CMessageWnd   constructor
//       TakeDown      hides and destroys window
//       
// Remarks             Used to create an initial non-user-controllable 
//                     message window when the application is run.
//========================================================================//
CMessageWnd::CMessageWnd()    //Class constructor
{
   const char *ClassName;  //Character string to hold the class name
      
   //
   //Register the class with defaults and standard background brush
   //
   ClassName = AfxRegisterWndClass(0, 0,
                                  (HBRUSH) (COLOR_WINDOW+1),0); 
      
   //
   //Measure up the splash window's rectangle
   //
   int left, top, width, height;
   width = GetSystemMetrics(SM_CXSCREEN) / 5;
   height = GetSystemMetrics(SM_CYSCREEN) / 9;
   left =  width * 1;  
   top =  height * 4;

   //
   //Create the window 
   //
   CreateEx(0,                            //No extended style
            ClassName,                    //ClassName as registered
            "Splash",                     //Window name
            WS_VISIBLE | WS_POPUP ,       //Visible window, no caption
            left, top, width * 3,height,  //Position & dimensions
            NULL, 0 , NULL);              //No parent,menu or extra param  

   //
   //Get window's client rectangle dimensions 
   //
   CRect SplashRect (0, 0, width * 3, height);

   //
   //Assign those dimensions to a region for the device context
   //
   CRgn SplashFrame;
   SplashFrame.CreateRectRgnIndirect(&SplashRect);
   
   //
   //Get the color of the brush to draw the frame with
   //
   CBrush FrameBrush (::GetSysColor (COLOR_ACTIVECAPTION));
   
   //
   //Get the device context
   //
   CDC* ClientDC = GetDC ();
   
   //
   //Draw the frame
   //
   ClientDC->FrameRgn(&SplashFrame, &FrameBrush, 5, 5);
   
   //
   //Free the region and the brush
   //
   SplashFrame.DeleteObject ();    
   FrameBrush.DeleteObject ();

   //
   //Set the text background mode to transparent
   //
   ClientDC->SetBkMode (TRANSPARENT);
   
   //
   //Calculate the size of the text to be shown
   //
   CString  ScanString("Scanning network for communications servers...");
   
   //
   //Find the size of the message in this DC
   //
   CSize ScanSize = ClientDC->GetTextExtent(ScanString, 
                                            ScanString.GetLength());
   
   // 
   //Calculate the position for the message in this window
   //
   ScanSize = SplashRect.Size() - ScanSize;
   
   //
   //Write the text message. Use TextOut, its faster
   //
   ClientDC->TextOut (ScanSize.cx / 2, ScanSize.cy / 2, ScanString);
   
   //
   //Now release the device context
   //
   ReleaseDC (ClientDC); 

}  //End CMessageWnd::CMessageWnd()    //Class constructor

   
//------------------------------------------------------------------------//
// CMessageWnd::TakeDown
// Parameters    none
// Returns       nothing
// Called by     CMainDialog::Create()
// Remarks       Hides and destroys the application's splash window
//------------------------------------------------------------------------//
void CMessageWnd::TakeDown()               
{
 ShowWindow(SW_HIDE);                     //First hide it
 DestroyWindow();                         //Now destroy it
} 

 